@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -30,7 +30,7 @@ import java.util.Objects;
 
 import org.apache.commons.compress.archivers.ArchiveEntry;
 import org.apache.commons.compress.utils.ExactMath;
-import org.apache.commons.compress.utils.TimeUtils;
+import org.apache.commons.io.file.attribute.FileTimes;
 
 /**
  * A cpio archive consists of a sequence of files. There are several types of headers defined in two categories of new and old format. The headers are
@@ -155,7 +155,7 @@ import org.apache.commons.compress.utils.TimeUtils;
  * </p>
  *
  * <p>
- * N.B. does not handle the cpio "tar" format
+ * Does not handle the cpio "tar" format
  * </p>
  *
  * @NotThreadSafe
@@ -181,7 +181,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     private long chksum;
 
     /** Number of bytes in the file */
-    private long filesize;
+    private long fileSize;
 
     private long gid;
 
@@ -314,7 +314,6 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      *                  </pre>
      *
      * @param options   options indicating how symbolic links are handled.
-     *
      * @throws IOException if an I/O error occurs
      * @since 1.21
      */
@@ -373,7 +372,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      */
     public CpioArchiveEntry(final short format, final String name, final long size) {
         this(format, name);
-        this.setSize(size);
+        setSize(size);
     }
 
     /**
@@ -393,7 +392,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      */
     public CpioArchiveEntry(final String name, final long size) {
         this(name);
-        this.setSize(size);
+        setSize(size);
     }
 
     /**
@@ -428,10 +427,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
             return false;
         }
         final CpioArchiveEntry other = (CpioArchiveEntry) obj;
-        if (name == null) {
-            return other.name == null;
-        }
-        return name.equals(other.name);
+        return Objects.equals(name, other.name);
     }
 
     /**
@@ -463,7 +459,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
         if (this.alignmentBoundary == 0) {
             return 0;
         }
-        final long size = this.filesize;
+        final long size = this.fileSize;
         final int remain = (int) (size % this.alignmentBoundary);
         if (remain > 0) {
             return this.alignmentBoundary - remain;
@@ -556,7 +552,6 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      *
      * @param nameSize The length of the name in bytes, as read in the stream. Without the trailing zero byte.
      * @return the number of bytes needed to pad the header (0,1,2,3)
-     *
      * @since 1.18
      */
     public int getHeaderPadCount(final long nameSize) {
@@ -598,7 +593,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Gets the mode of this entry (e.g. directory, regular file).
+     * Gets the mode of this entry (for example directory, regular file).
      *
      * @return the mode.
      */
@@ -663,14 +658,14 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Gets the filesize.
+     * Gets the file size.
      *
-     * @return the filesize.
+     * @return the file size.
      * @see org.apache.commons.compress.archivers.ArchiveEntry#getSize()
      */
     @Override
     public long getSize() {
-        return this.filesize;
+        return this.fileSize;
     }
 
     /**
@@ -834,7 +829,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Sets the mode of this entry (e.g. directory, regular file).
+     * Sets the mode of this entry (for example directory, regular file).
      *
      * @param mode The mode to set.
      */
@@ -851,7 +846,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
         case C_ISNWK:
             break;
         default:
-            throw new IllegalArgumentException("Unknown mode. " + "Full: " + Long.toHexString(mode) + " Masked: " + Long.toHexString(maskedMode));
+            throw new IllegalArgumentException("Unknown mode. Full: " + Long.toHexString(mode) + " Masked: " + Long.toHexString(maskedMode));
         }
 
         this.mode = mode;
@@ -909,15 +904,15 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
     }
 
     /**
-     * Sets the filesize.
+     * Sets the file size.
      *
-     * @param size The filesize to set.
+     * @param size The file size to set.
      */
     public void setSize(final long size) {
         if (size < 0 || size > 0xFFFFFFFFL) {
             throw new IllegalArgumentException("Invalid entry size <" + size + ">");
         }
-        this.filesize = size;
+        this.fileSize = size;
     }
 
     /**
@@ -926,7 +921,7 @@ public class CpioArchiveEntry implements CpioConstants, ArchiveEntry {
      * @param time The time to set.
      */
     public void setTime(final FileTime time) {
-        this.mtime = TimeUtils.toUnixTime(time);
+        this.mtime = FileTimes.toUnixTime(time);
     }
 
     /**
