@@ -1,18 +1,20 @@
 /*
- *  Licensed to the Apache Software Foundation (ASF) under one or more
- *  contributor license agreements.  See the NOTICE file distributed with
- *  this work for additional information regarding copyright ownership.
- *  The ASF licenses this file to You under the Apache License, Version 2.0
- *  (the "License"); you may not use this file except in compliance with
- *  the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 
 /*
@@ -37,25 +39,30 @@ import org.apache.commons.compress.archivers.ArchiveInputStream;
 import org.apache.commons.compress.archivers.zip.ZipEncoding;
 import org.apache.commons.compress.archivers.zip.ZipEncodingHelper;
 import org.apache.commons.compress.utils.ArchiveUtils;
-import org.apache.commons.compress.utils.BoundedInputStream;
 import org.apache.commons.compress.utils.IOUtils;
+import org.apache.commons.io.input.BoundedInputStream;
 
 /**
- * The TarInputStream reads a UNIX tar archive as an InputStream. methods are provided to position at each successive entry in the archive, and the read each
+ * The TarInputStream reads a Unix tar archive as an InputStream. methods are provided to position at each successive entry in the archive, and the read each
  * entry as a normal input stream using read().
  *
  * @NotThreadSafe
  */
 public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
 
+    /**
+     * IBM AIX <a href=""https://www.ibm.com/docs/sv/aix/7.2.0?topic=files-tarh-file">tar.h</a>: "This field is terminated with a space only."
+     */
+    private static final String VERSION_AIX = "0 ";
+
     private static final int SMALL_BUFFER_SIZE = 256;
 
     /**
      * Checks if the signature matches what is expected for a tar file.
      *
-     * @param signature the bytes to check
-     * @param length    the number of bytes to check
-     * @return true, if this stream is a tar archive stream, false otherwise
+     * @param signature the bytes to check.
+     * @param length    the number of bytes to check.
+     * @return true, if this stream is a tar archive stream, false otherwise.
      */
     public static boolean matches(final byte[] signature, final int length) {
         final int versionOffset = TarConstants.VERSION_OFFSET;
@@ -63,13 +70,17 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
         if (length < versionOffset + versionLen) {
             return false;
         }
-
         final int magicOffset = TarConstants.MAGIC_OFFSET;
         final int magicLen = TarConstants.MAGICLEN;
         if (ArchiveUtils.matchAsciiBuffer(TarConstants.MAGIC_POSIX, signature, magicOffset, magicLen)
                 && ArchiveUtils.matchAsciiBuffer(TarConstants.VERSION_POSIX, signature, versionOffset, versionLen)) {
             return true;
         }
+        // IBM AIX tar.h https://www.ibm.com/docs/sv/aix/7.2.0?topic=files-tarh-file : "This field is terminated with a space only."
+        if (ArchiveUtils.matchAsciiBuffer(TarConstants.MAGIC_POSIX, signature, magicOffset, magicLen)
+                && ArchiveUtils.matchAsciiBuffer(VERSION_AIX, signature, versionOffset, versionLen)) {
+            return true;
+        }
         if (ArchiveUtils.matchAsciiBuffer(TarConstants.MAGIC_GNU, signature, magicOffset, magicLen)
                 && (ArchiveUtils.matchAsciiBuffer(TarConstants.VERSION_GNU_SPACE, signature, versionOffset, versionLen)
                         || ArchiveUtils.matchAsciiBuffer(TarConstants.VERSION_GNU_ZERO, signature, versionOffset, versionLen))) {
@@ -82,9 +93,6 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
 
     private final byte[] smallBuf = new byte[SMALL_BUFFER_SIZE];
 
-    /** The size the TAR header. */
-    private final int recordSize;
-
     /** The buffer to store the TAR header. **/
     private final byte[] recordBuffer;
 
@@ -188,9 +196,7 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
      */
     public TarArchiveInputStream(final InputStream inputStream, final int blockSize, final int recordSize, final String encoding, final boolean lenient) {
         super(inputStream, encoding);
-        this.atEof = false;
         this.zipEncoding = ZipEncodingHelper.getZipEncoding(encoding);
-        this.recordSize = recordSize;
         this.recordBuffer = new byte[recordSize];
         this.blockSize = blockSize;
         this.lenient = lenient;
@@ -237,17 +243,19 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
         if (isDirectory()) {
             return 0;
         }
-        if (currEntry.getRealSize() - entryOffset > Integer.MAX_VALUE) {
+        final long available = currEntry.getRealSize() - entryOffset;
+        if (available > Integer.MAX_VALUE) {
             return Integer.MAX_VALUE;
         }
-        return (int) (currEntry.getRealSize() - entryOffset);
+        return (int) available;
     }
 
     /**
      * Build the input streams consisting of all-zero input streams and non-zero input streams. When reading from the non-zero input streams, the data is
      * actually read from the original input stream. The size of each input stream is introduced by the sparse headers.
-     *
+     * <p>
      * NOTE : Some all-zero input streams and non-zero input streams have the size of 0. We DO NOT store the 0 size input streams because they are meaningless.
+     * </p>
      */
     private void buildSparseInputStreams() throws IOException {
         currentSparseInputStreamIndex = -1;
@@ -265,33 +273,39 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
                 // sparse header says to move backwards inside the extracted entry
                 throw new IOException("Corrupted struct sparse detected");
             }
-
             // only store the zero block if it is not empty
             if (zeroBlockSize > 0) {
-                sparseInputStreams.add(new BoundedInputStream(zeroInputStream, sparseHeader.getOffset() - offset));
+                // @formatter:off
+                sparseInputStreams.add(BoundedInputStream.builder()
+                        .setInputStream(zeroInputStream)
+                        .setMaxCount(sparseHeader.getOffset() - offset)
+                        .get());
+                // @formatter:on
             }
-
             // only store the input streams with non-zero size
             if (sparseHeader.getNumbytes() > 0) {
-                sparseInputStreams.add(new BoundedInputStream(in, sparseHeader.getNumbytes()));
+                // @formatter:off
+                sparseInputStreams.add(BoundedInputStream.builder()
+                        .setInputStream(in)
+                        .setMaxCount(sparseHeader.getNumbytes())
+                        .get());
+                // @formatter:on
             }
-
             offset = sparseHeader.getOffset() + sparseHeader.getNumbytes();
         }
-
         if (!sparseInputStreams.isEmpty()) {
             currentSparseInputStreamIndex = 0;
         }
     }
 
     /**
-     * Whether this class is able to read the given entry.
+     * Tests whether this class is able to read the given entry.
      *
      * @return The implementation will return true if the {@link ArchiveEntry} is an instance of {@link TarArchiveEntry}
      */
     @Override
-    public boolean canReadEntryData(final ArchiveEntry ae) {
-        return ae instanceof TarArchiveEntry;
+    public boolean canReadEntryData(final ArchiveEntry archiveEntry) {
+        return archiveEntry instanceof TarArchiveEntry;
     }
 
     /**
@@ -307,7 +321,6 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
                 inputStream.close();
             }
         }
-
         in.close();
     }
 
@@ -318,8 +331,7 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
     private void consumeRemainderOfLastBlock() throws IOException {
         final long bytesReadOfLastBlock = getBytesRead() % blockSize;
         if (bytesReadOfLastBlock > 0) {
-            final long skipped = org.apache.commons.io.IOUtils.skip(in, blockSize - bytesReadOfLastBlock);
-            count(skipped);
+            count(IOUtils.skip(in, blockSize - bytesReadOfLastBlock));
         }
     }
 
@@ -337,11 +349,9 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
         if (in instanceof FileInputStream) {
             actuallySkipped = Math.min(skipped, available);
         }
-
         if (actuallySkipped != expected) {
             throw new IOException("Truncated TAR archive");
         }
-
         return actuallySkipped;
     }
 
@@ -386,7 +396,7 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
     }
 
     /**
-     * Returns the next Archive Entry in this Stream.
+     * Gets the next TarArchiveEntry in this stream.
      *
      * @return the next entry, or {@code null} if there are no more entries
      * @throws IOException if the next entry could not be read
@@ -410,52 +420,41 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
         if (isAtEOF()) {
             return null;
         }
-
         if (currEntry != null) {
             /* Skip will only go to the end of the current entry */
-            org.apache.commons.io.IOUtils.skip(this, Long.MAX_VALUE);
-
+            IOUtils.skip(this, Long.MAX_VALUE);
             /* skip to the end of the last record */
             skipRecordPadding();
         }
-
         final byte[] headerBuf = getRecord();
-
         if (headerBuf == null) {
             /* hit EOF */
             currEntry = null;
             return null;
         }
-
         try {
             currEntry = new TarArchiveEntry(globalPaxHeaders, headerBuf, zipEncoding, lenient);
         } catch (final IllegalArgumentException e) {
             throw new IOException("Error detected parsing the header", e);
         }
-
         entryOffset = 0;
         entrySize = currEntry.getSize();
-
         if (currEntry.isGNULongLinkEntry()) {
             final byte[] longLinkData = getLongNameData();
             if (longLinkData == null) {
                 // Bugzilla: 40334
-                // Malformed tar file - long link entry name not followed by
-                // entry
+                // Malformed tar file - long link entry name not followed by entry
                 return null;
             }
             currEntry.setLinkName(zipEncoding.decode(longLinkData));
         }
-
         if (currEntry.isGNULongNameEntry()) {
             final byte[] longNameData = getLongNameData();
             if (longNameData == null) {
                 // Bugzilla: 40334
-                // Malformed tar file - long entry name not followed by
-                // entry
+                // Malformed tar file - long entry name not followed by entry
                 return null;
             }
-
             // COMPRESS-509 : the name of directories should end with '/'
             final String name = zipEncoding.decode(longNameData);
             currEntry.setName(name);
@@ -463,11 +462,9 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
                 currEntry.setName(name + "/");
             }
         }
-
         if (currEntry.isGlobalPaxHeader()) { // Process Global Pax headers
             readGlobalPaxHeaders();
         }
-
         try {
             if (currEntry.isPaxHeader()) { // Process Pax headers
                 paxHeaders();
@@ -477,24 +474,20 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
         } catch (final NumberFormatException e) {
             throw new IOException("Error detected parsing the pax header", e);
         }
-
         if (currEntry.isOldGNUSparse()) { // Process sparse files
             readOldGNUSparse();
         }
-
         // If the size of the next element in the archive has changed
-        // due to a new size being reported in the posix header
+        // due to a new size being reported in the POSIX header
         // information, we update entrySize here so that it contains
         // the correct value.
         entrySize = currEntry.getSize();
-
         return currEntry;
     }
 
     /**
      * Gets the next record in this tar archive. This will skip over any remaining data in the current entry, if there is one, and place the input stream at the
      * header of the next entry.
-     *
      * <p>
      * If there are no more entries in the archive, null will be returned to indicate that the end of the archive has been reached. At the same time the
      * {@code hasHitEOF} marker will be set to true.
@@ -520,9 +513,14 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
      * @return The TarBuffer record size.
      */
     public int getRecordSize() {
-        return recordSize;
+        return recordBuffer.length;
     }
 
+    /**
+     * Tests whether we are at the end-of-file.
+     *
+     * @return whether we are at the end-of-file.
+     */
     protected final boolean isAtEOF() {
         return atEof;
     }
@@ -532,13 +530,13 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
     }
 
     /**
-     * Determine if an archive record indicate End of Archive. End of archive is indicated by a record that consists entirely of null bytes.
+     * Tests if an archive record indicate End of Archive. End of archive is indicated by a record that consists entirely of null bytes.
      *
      * @param record The record data to check.
      * @return true if the record data is an End of Archive
      */
     protected boolean isEOFRecord(final byte[] record) {
-        return record == null || ArchiveUtils.isArrayZero(record, recordSize);
+        return record == null || ArchiveUtils.isArrayZero(record, getRecordSize());
     }
 
     /**
@@ -553,7 +551,7 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
     /**
      * Since we do not support marking just yet, we return false.
      *
-     * @return False.
+     * @return false.
      */
     @Override
     public boolean markSupported() {
@@ -562,25 +560,26 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
 
     /**
      * For PAX Format 0.0, the sparse headers(GNU.sparse.offset and GNU.sparse.numbytes) may appear multi times, and they look like:
-     *
+     * <p>
      * GNU.sparse.size=size GNU.sparse.numblocks=numblocks repeat numblocks times GNU.sparse.offset=offset GNU.sparse.numbytes=numbytes end repeat
-     *
-     *
+     * </p>
+     * <p>
      * For PAX Format 0.1, the sparse headers are stored in a single variable : GNU.sparse.map
-     *
+     * </p>
+     * <p>
      * GNU.sparse.map Map of non-null data chunks. It is a string consisting of comma-separated values "offset,size[,offset-1,size-1...]"
-     *
-     *
+     * </p>
+     * <p>
      * For PAX Format 1.X: The sparse map itself is stored in the file data block, preceding the actual file data. It consists of a series of decimal numbers
      * delimited by newlines. The map is padded with nulls to the nearest block boundary. The first number gives the number of entries in the map. Following are
      * map entries, each one consisting of two numbers giving the offset and size of the data block it describes.
+     * </p>
      *
-     * @throws IOException
+     * @throws IOException if an I/O error occurs.
      */
     private void paxHeaders() throws IOException {
         List<TarArchiveStructSparse> sparseHeaders = new ArrayList<>();
         final Map<String, String> headers = TarUtils.parsePaxHeaders(this, sparseHeaders, globalPaxHeaders, entrySize);
-
         // for 0.1 PAX Headers
         if (headers.containsKey(TarGnuSparseKeys.MAP)) {
             sparseHeaders = new ArrayList<>(TarUtils.parseFromPAX01SparseHeaders(headers.get(TarGnuSparseKeys.MAP)));
@@ -590,13 +589,11 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
             throw new IOException("premature end of tar archive. Didn't find any entry after PAX header.");
         }
         applyPaxHeadersToCurrentEntry(headers, sparseHeaders);
-
         // for 1.0 PAX Format, the sparse map is stored in the file data block
         if (currEntry.isPaxGNU1XSparse()) {
-            sparseHeaders = TarUtils.parsePAX1XSparseHeaders(in, recordSize);
+            sparseHeaders = TarUtils.parsePAX1XSparseHeaders(in, getRecordSize());
             currEntry.setSparseHeaders(sparseHeaders);
         }
-
         // sparse headers are all done reading, we need to build
         // sparse input streams using these sparse headers
         buildSparseInputStreams();
@@ -604,8 +601,9 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
 
     /**
      * Reads bytes from the current tar archive entry.
-     *
+     * <p>
      * This method is aware of the boundaries of the current entry in the archive and will deal with them as if they were this stream's start and EOF.
+     * </p>
      *
      * @param buf       The buffer into which to place bytes read.
      * @param offset    The offset at which to place bytes read.
@@ -619,28 +617,22 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
             return 0;
         }
         int totalRead = 0;
-
         if (isAtEOF() || isDirectory()) {
             return -1;
         }
-
         if (currEntry == null) {
             throw new IllegalStateException("No current tar entry");
         }
-
         if (entryOffset >= currEntry.getRealSize()) {
             return -1;
         }
-
         numToRead = Math.min(numToRead, available());
-
         if (currEntry.isSparse()) {
             // for sparse entries, we need to read them in another way
             totalRead = readSparse(buf, offset, numToRead);
         } else {
             totalRead = in.read(buf, offset, numToRead);
         }
-
         if (totalRead == -1) {
             if (numToRead > 0) {
                 throw new IOException("Truncated TAR archive");
@@ -650,14 +642,12 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
             count(totalRead);
             entryOffset += totalRead;
         }
-
         return totalRead;
     }
 
     private void readGlobalPaxHeaders() throws IOException {
         globalPaxHeaders = TarUtils.parsePaxHeaders(this, globalSparseHeaders, globalPaxHeaders, entrySize);
         getNextEntry(); // Get the actual file entry
-
         if (currEntry == null) {
             throw new IOException("Error detected parsing the pax header");
         }
@@ -680,25 +670,23 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
                 currEntry.getSparseHeaders().addAll(entry.getSparseHeaders());
             } while (entry.isExtended());
         }
-
         // sparse headers are all done reading, we need to build
         // sparse input streams using these sparse headers
         buildSparseInputStreams();
     }
 
     /**
-     * Read a record from the input stream and return the data.
+     * Reads a record from the input stream and return the data.
      *
      * @return The record data or null if EOF has been hit.
      * @throws IOException on error
      */
     protected byte[] readRecord() throws IOException {
-        final int readNow = IOUtils.readFully(in, recordBuffer);
-        count(readNow);
-        if (readNow != recordSize) {
+        final int readCount = IOUtils.readFully(in, recordBuffer);
+        count(readCount);
+        if (readCount != getRecordSize()) {
             return null;
         }
-
         return recordBuffer;
     }
 
@@ -719,26 +707,21 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
         if (sparseInputStreams == null || sparseInputStreams.isEmpty()) {
             return in.read(buf, offset, numToRead);
         }
-
         if (currentSparseInputStreamIndex >= sparseInputStreams.size()) {
             return -1;
         }
-
         final InputStream currentInputStream = sparseInputStreams.get(currentSparseInputStreamIndex);
         final int readLen = currentInputStream.read(buf, offset, numToRead);
-
         // if the current input stream is the last input stream,
         // just return the number of bytes read from current input stream
         if (currentSparseInputStreamIndex == sparseInputStreams.size() - 1) {
             return readLen;
         }
-
         // if EOF of current input stream is meet, open a new input stream and recursively call read
         if (readLen == -1) {
             currentSparseInputStreamIndex++;
             return readSparse(buf, offset, numToRead);
         }
-
         // if the rest data of current input stream is not long enough, open a new input stream
         // and recursively call read
         if (readLen < numToRead) {
@@ -747,10 +730,8 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
             if (readLenOfNext == -1) {
                 return readLen;
             }
-
             return readLen + readLenOfNext;
         }
-
         // if the rest data of current input stream is enough(which means readLen == len), just return readLen
         return readLen;
     }
@@ -760,14 +741,25 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
      */
     @Override
     public synchronized void reset() {
+        // empty
     }
 
-    protected final void setAtEOF(final boolean b) {
-        atEof = b;
+    /**
+     * Sets whether we are at the end-of-file.
+     *
+     * @param atEof whether we are at the end-of-file.
+     */
+    protected final void setAtEOF(final boolean atEof) {
+        this.atEof = atEof;
     }
 
-    protected final void setCurrentEntry(final TarArchiveEntry e) {
-        currEntry = e;
+    /**
+     * Sets the current entry.
+     *
+     * @param currEntry the current entry.
+     */
+    protected final void setCurrentEntry(final TarArchiveEntry currEntry) {
+        this.currEntry = currEntry;
     }
 
     /**
@@ -775,7 +767,6 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
      * smaller number of bytes, possibly {@code 0}. This may result from any of a number of conditions; reaching end of file or end of entry before {@code n}
      * bytes have been skipped; are only two possibilities. The actual number of bytes skipped is returned. If {@code n} is negative, no bytes are skipped.
      *
-     *
      * @param n the number of bytes to be skipped.
      * @return the actual number of bytes skipped.
      * @throws IOException if a truncated tar archive is detected or some other I/O error occurs
@@ -785,21 +776,18 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
         if (n <= 0 || isDirectory()) {
             return 0;
         }
-
         final long availableOfInputStream = in.available();
         final long available = currEntry.getRealSize() - entryOffset;
         final long numToSkip = Math.min(n, available);
         long skipped;
-
         if (!currEntry.isSparse()) {
-            skipped = org.apache.commons.io.IOUtils.skip(in, numToSkip);
+            skipped = IOUtils.skip(in, numToSkip);
             // for non-sparse entry, we should get the bytes actually skipped bytes along with
             // inputStream.available() if inputStream is instance of FileInputStream
             skipped = getActuallySkipped(availableOfInputStream, skipped, numToSkip);
         } else {
             skipped = skipSparse(numToSkip);
         }
-
         count(skipped);
         entryOffset += skipped;
         return skipped;
@@ -811,14 +799,12 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
      * @throws IOException if a truncated tar archive is detected
      */
     private void skipRecordPadding() throws IOException {
-        if (!isDirectory() && this.entrySize > 0 && this.entrySize % this.recordSize != 0) {
+        if (!isDirectory() && this.entrySize > 0 && this.entrySize % getRecordSize() != 0) {
             final long available = in.available();
-            final long numRecords = this.entrySize / this.recordSize + 1;
-            final long padding = numRecords * this.recordSize - this.entrySize;
-            long skipped = org.apache.commons.io.IOUtils.skip(in, padding);
-
+            final long numRecords = this.entrySize / getRecordSize() + 1;
+            final long padding = numRecords * getRecordSize() - this.entrySize;
+            long skipped = IOUtils.skip(in, padding);
             skipped = getActuallySkipped(available, skipped, padding);
-
             count(skipped);
         }
     }
@@ -829,30 +815,25 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
      *
      * @param n bytes of data to skip
      * @return actual bytes of data skipped
-     * @throws IOException
+     * @throws IOException if an I/O error occurs.
      */
     private long skipSparse(final long n) throws IOException {
         if (sparseInputStreams == null || sparseInputStreams.isEmpty()) {
             return in.skip(n);
         }
-
         long bytesSkipped = 0;
-
         while (bytesSkipped < n && currentSparseInputStreamIndex < sparseInputStreams.size()) {
             final InputStream currentInputStream = sparseInputStreams.get(currentSparseInputStreamIndex);
             bytesSkipped += currentInputStream.skip(n - bytesSkipped);
-
             if (bytesSkipped < n) {
                 currentSparseInputStreamIndex++;
             }
         }
-
         return bytesSkipped;
     }
 
     /**
      * Tries to read the next record rewinding the stream if it is not an EOF record.
-     *
      * <p>
      * This is meant to protect against cases where a tar implementation has written only one EOF record when two are expected. Actually this won't help since a
      * non-conforming implementation likely won't fill full blocks consisting of - by default - ten records either so we probably have already read beyond the
@@ -863,13 +844,13 @@ public class TarArchiveInputStream extends ArchiveInputStream<TarArchiveEntry> {
         boolean shouldReset = true;
         final boolean marked = in.markSupported();
         if (marked) {
-            in.mark(recordSize);
+            in.mark(getRecordSize());
         }
         try {
             shouldReset = !isEOFRecord(readRecord());
         } finally {
             if (shouldReset && marked) {
-                pushedBackBytes(recordSize);
+                pushedBackBytes(getRecordSize());
                 in.reset();
             }
         }
