@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -19,6 +19,7 @@
 package org.apache.commons.compress.archivers;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -34,6 +35,7 @@ import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
+import java.util.Objects;
 import java.util.stream.Stream;
 
 import org.apache.commons.compress.AbstractTest;
@@ -50,7 +52,7 @@ import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.MethodSource;
 
-public class ArchiveStreamFactoryTest extends AbstractTest {
+class ArchiveStreamFactoryTest extends AbstractTest {
 
     static class TestData {
         final String testFile;
@@ -153,16 +155,8 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
             new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, StandardCharsets.UTF_8.name(), FACTORY_SET_UTF8, "charset"),
             new TestData("bla.zip", ArchiveStreamFactory.ZIP, true, StandardCharsets.US_ASCII.name(), FACTORY_SET_ASCII, "charset"), };
 
-    /** equals allowing null. */
-    private static boolean eq(final String exp, final String act) {
-        if (exp == null) {
-            return act == null;
-        }
-        return exp.equals(act);
-    }
-
-    private static String getCharsetName(final ArchiveInputStream<?> instance) {
-        return instance.getCharset().name();
+    private static String getCharsetName(final ArchiveInputStream<?> inputStream) {
+        return inputStream.getCharset().name();
     }
 
     @SuppressWarnings("deprecation") // test of deprecated method
@@ -197,6 +191,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
         }
     }
 
+    @SuppressWarnings("resource") // Caller closes
     public static Stream<Path> getIcoPathStream() throws IOException {
         return Files.walk(Paths.get("src/test/resources/org/apache/commons/compress/ico")).filter(Files::isRegularFile);
     }
@@ -228,7 +223,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
      * see https://issues.apache.org/jira/browse/COMPRESS-191
      */
     @Test
-    public void testAiffFilesAreNoTARs() throws Exception {
+    void testAiffFilesAreNoTARs() throws Exception {
         try (InputStream fis = newInputStream("testAIFF.aif");
                 InputStream is = new BufferedInputStream(fis)) {
             final ArchiveException ae = assertThrows(ArchiveException.class, () -> ArchiveStreamFactory.DEFAULT.createArchiveInputStream(is),
@@ -238,19 +233,19 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     }
 
     @Test
-    public void testCantRead7zFromStream() throws Exception {
+    void testCantRead7zFromStream() throws Exception {
         assertThrows(StreamingNotSupportedException.class, () -> ArchiveStreamFactory.DEFAULT.createArchiveInputStream(ArchiveStreamFactory.SEVEN_Z,
                 new ByteArrayInputStream(ByteUtils.EMPTY_BYTE_ARRAY)));
     }
 
     @Test
-    public void testCantWrite7zToStream() throws Exception {
+    void testCantWrite7zToStream() throws Exception {
         assertThrows(StreamingNotSupportedException.class,
                 () -> ArchiveStreamFactory.DEFAULT.createArchiveOutputStream(ArchiveStreamFactory.SEVEN_Z, new ByteArrayOutputStream()));
     }
 
     @Test
-    public void testCOMPRESS209() throws Exception {
+    void testCOMPRESS209() throws Exception {
         try (InputStream fis = newInputStream("testCompress209.doc");
                 InputStream bis = new BufferedInputStream(fis)) {
             final ArchiveException ae = assertThrows(ArchiveException.class, () -> ArchiveStreamFactory.DEFAULT.createArchiveInputStream(bis),
@@ -260,7 +255,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     }
 
     @Test
-    public void testDetect() throws Exception {
+    void testDetect() throws Exception {
         for (final String extension : new String[] { ArchiveStreamFactory.AR, ArchiveStreamFactory.ARJ, ArchiveStreamFactory.CPIO, ArchiveStreamFactory.DUMP,
                 // Compress doesn't know how to detect JARs, see COMPRESS-91
                 // ArchiveStreamFactory.JAR,
@@ -279,14 +274,14 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
 
         final ArchiveException e3 = assertThrows(ArchiveException.class, () -> ArchiveStreamFactory.detect(new BufferedInputStream(new BrokenInputStream())),
                 "Expected ArchiveException");
-        assertEquals("IOException while reading signature.", e3.getMessage());
+        assertEquals("Failure reading signature.", e3.getMessage());
     }
 
     /**
-     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-267" >COMPRESS-267</a>.
+     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-267">COMPRESS-267</a>.
      */
     @Test
-    public void testDetectsAndThrowsFor7z() throws Exception {
+    void testDetectsAndThrowsFor7z() throws Exception {
         try (InputStream fis = newInputStream("bla.7z");
                 InputStream bis = new BufferedInputStream(fis)) {
             final StreamingNotSupportedException ex = assertThrows(StreamingNotSupportedException.class,
@@ -296,7 +291,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     }
 
     @Test
-    public void testEncodingCtor() {
+    void testEncodingCtor() {
         ArchiveStreamFactory fac = new ArchiveStreamFactory();
         assertNull(fac.getEntryEncoding());
         fac = new ArchiveStreamFactory(null);
@@ -307,7 +302,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
 
     @Test
     @SuppressWarnings("deprecation")
-    public void testEncodingDeprecated() {
+    void testEncodingDeprecated() {
         final ArchiveStreamFactory fac1 = new ArchiveStreamFactory();
         assertNull(fac1.getEntryEncoding());
         fac1.setEntryEncoding(StandardCharsets.UTF_8.name());
@@ -321,13 +316,13 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     }
 
     @Test
-    public void testEncodingInputStream() throws Exception {
+    void testEncodingInputStream() throws Exception {
         int failed = 0;
         for (int i = 1; i <= TESTS.length; i++) {
             final TestData test = TESTS[i - 1];
             try (ArchiveInputStream<?> ais = getInputStream(test.type, test.testFile, test.fac)) {
                 final String field = getCharsetName(ais);
-                if (!eq(test.expectedEncoding, field)) {
+                if (!Objects.equals(field, field)) {
                     System.err.println("Failed test " + i + ". expected: " + test.expectedEncoding + " actual: " + field + " type: " + test.type);
                     failed++;
                 }
@@ -339,13 +334,13 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     }
 
     @Test
-    public void testEncodingInputStreamAutodetect() throws Exception {
+    void testEncodingInputStreamAutodetect() throws Exception {
         int failed = 0;
         for (int i = 1; i <= TESTS.length; i++) {
             final TestData test = TESTS[i - 1];
             try (ArchiveInputStream<?> ais = getInputStream(test.testFile, test.fac)) {
                 final String field = getCharsetName(ais);
-                if (!eq(test.expectedEncoding, field)) {
+                if (!Objects.equals(field, field)) {
                     System.err.println("Failed test " + i + ". expected: " + test.expectedEncoding + " actual: " + field + " type: " + test.type);
                     failed++;
                 }
@@ -357,14 +352,14 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     }
 
     @Test
-    public void testEncodingOutputStream() throws Exception {
+    void testEncodingOutputStream() throws Exception {
         int failed = 0;
         for (int i = 1; i <= TESTS.length; i++) {
             final TestData test = TESTS[i - 1];
             if (test.hasOutputStream) {
                 try (ArchiveOutputStream<?> ais = getOutputStream(test.type, test.fac)) {
                     final String field = getFieldAsString(ais, test.fieldName);
-                    if (!eq(test.expectedEncoding, field)) {
+                    if (!Objects.equals(field, field)) {
                         System.err.println("Failed test " + i + ". expected: " + test.expectedEncoding + " actual: " + field + " type: " + test.type);
                         failed++;
                     }
@@ -378,7 +373,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
 
     @ParameterizedTest
     @MethodSource("getIcoPathStream")
-    public void testIcoFilesAreNoTARs(final Path path) throws Exception {
+    void testIcoFilesAreNoTARs(final Path path) throws Exception {
         try (InputStream fis = Files.newInputStream(path);
                 InputStream is = new BufferedInputStream(fis)) {
             final ArchiveException ae = assertThrows(ArchiveException.class, () -> ArchiveStreamFactory.detect(is),
@@ -397,7 +392,7 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
      * See https://issues.apache.org/jira/browse/COMPRESS-171
      */
     @Test
-    public void testShortTextFilesAreNoTARs() {
+    void testShortTextFilesAreNoTARs() {
         final ArchiveException ae = assertThrows(ArchiveException.class,
                 () -> ArchiveStreamFactory.DEFAULT
                         .createArchiveInputStream(new ByteArrayInputStream("This certainly is not a tar archive, really, no kidding".getBytes())),
@@ -406,16 +401,36 @@ public class ArchiveStreamFactoryTest extends AbstractTest {
     }
 
     /**
-     * Tests case for <a href="https://issues.apache.org/jira/browse/COMPRESS-208" >COMPRESS-208</a>.
+     * Tests case for <a href="https://issues.apache.org/jira/browse/COMPRESS-208">COMPRESS-208</a>.
      */
     @Test
-    public void testSkipsPK00Prefix() throws Exception {
+    void testSkipsPK00Prefix() throws Exception {
         try (InputStream fis = newInputStream("COMPRESS-208.zip")) {
             try (InputStream bis = new BufferedInputStream(fis)) {
                 try (ArchiveInputStream<?> ais = ArchiveStreamFactory.DEFAULT.createArchiveInputStream(bis)) {
-                    assertTrue(ais instanceof ZipArchiveInputStream);
+                    assertInstanceOf(ZipArchiveInputStream.class, ais);
                 }
             }
         }
     }
+
+    @Test
+    void testTarContainingDirWith1TxtFileIsTAR() throws IOException, ArchiveException {
+        assertEquals(ArchiveStreamFactory.TAR, detect("dirWith1TxtFile.tar"));
+    }
+
+    @Test
+    void testTarContainingEmptyDirIsTAR() throws IOException, ArchiveException {
+        assertEquals(ArchiveStreamFactory.TAR, detect("emptyDir.tar"));
+    }
+
+    /**
+     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-674">COMPRESS-674</a>.
+     */
+    @Test
+    void testUtf16TextIsNotTAR() {
+        final ArchiveException archiveException = assertThrows(ArchiveException.class,
+                () -> detect("utf16-text.txt"));
+        assertEquals("No Archiver found for the stream signature", archiveException.getMessage());
+    }
 }
