@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -70,20 +70,20 @@ public final class ZipTest extends AbstractTest {
 
     final ZipArchiveEntryPredicate allFilesPredicate = zipArchiveEntry -> true;
 
-    private void addFilesToZip(final ZipArchiveOutputStream zipArchiveOutputStream, final File fileToAdd) throws IOException {
+    private void addFilesToZip(final ZipArchiveOutputStream outputStream, final File fileToAdd) throws IOException {
         if (fileToAdd.isDirectory()) {
             for (final File file : fileToAdd.listFiles()) {
-                addFilesToZip(zipArchiveOutputStream, file);
+                addFilesToZip(outputStream, file);
             }
         } else {
             final ZipArchiveEntry zipArchiveEntry = new ZipArchiveEntry(fileToAdd.getPath());
             zipArchiveEntry.setMethod(ZipEntry.DEFLATED);
 
-            zipArchiveOutputStream.putArchiveEntry(zipArchiveEntry);
+            outputStream.putArchiveEntry(zipArchiveEntry);
             try {
-                Files.copy(fileToAdd.toPath(), zipArchiveOutputStream);
+                outputStream.write(fileToAdd);
             } finally {
-                zipArchiveOutputStream.closeArchiveEntry();
+                outputStream.closeArchiveEntry();
             }
         }
     }
@@ -184,32 +184,17 @@ public final class ZipTest extends AbstractTest {
     private File getFilesToZip() throws IOException {
         final File originalZipFile = getFile("COMPRESS-477/split_zip_created_by_zip/zip_to_compare_created_by_zip.zip");
         try (ZipFile zipFile = newZipFile(originalZipFile)) {
-            final Enumeration<ZipArchiveEntry> zipEntries = zipFile.getEntries();
-            ZipArchiveEntry zipEntry;
-            File outputFile;
-            byte[] buffer;
-            int readLen;
-
-            while (zipEntries.hasMoreElements()) {
-                zipEntry = zipEntries.nextElement();
-                if (zipEntry.isDirectory()) {
-                    continue;
+            zipFile.stream().filter(e -> !e.isDirectory()).forEach(zipEntry -> {
+                Path outputFile = newTempPath(zipEntry.getName());
+                if (!Files.exists(outputFile.getParent())) {
+                    Files.createDirectories(outputFile.getParent());
                 }
-
-                outputFile = newTempFile(zipEntry.getName());
-                if (!outputFile.getParentFile().exists()) {
-                    outputFile.getParentFile().mkdirs();
-                }
-                outputFile = newTempFile(zipEntry.getName());
-
+                outputFile = newTempPath(zipEntry.getName());
                 try (InputStream inputStream = zipFile.getInputStream(zipEntry);
-                        OutputStream outputStream = Files.newOutputStream(outputFile.toPath())) {
-                    buffer = new byte[(int) zipEntry.getSize()];
-                    while ((readLen = inputStream.read(buffer)) > 0) {
-                        outputStream.write(buffer, 0, readLen);
-                    }
+                        OutputStream outputStream = Files.newOutputStream(outputFile)) {
+                    IOUtils.copy(inputStream, outputStream);
                 }
-            }
+            });
         }
         return getTempDirFile().listFiles()[0];
     }
@@ -219,15 +204,10 @@ public final class ZipTest extends AbstractTest {
     }
 
     private void readStream(final InputStream in, final ArchiveEntry entry, final Map<String, List<List<Long>>> map) throws IOException {
-        final byte[] buf = new byte[4096];
         final InputStreamStatistics stats = (InputStreamStatistics) in;
-        while (in.read(buf) != -1) {
-            // consume all.
-        }
-
+        IOUtils.consume(in);
         final String name = entry.getName();
         final List<List<Long>> list = map.computeIfAbsent(name, k -> new ArrayList<>());
-
         final long t = stats.getUncompressedCount();
         final long b = stats.getCompressedCount();
         list.add(Arrays.asList(t, b));
@@ -237,21 +217,21 @@ public final class ZipTest extends AbstractTest {
      * Tests split archive with 32-bit limit, both STORED and DEFLATED.
      */
     @Test
-    public void testBuildArtificialSplitZip32Test() throws IOException {
+    void testBuildArtificialSplitZip32Test() throws IOException {
         final File outputZipFile = newTempFile("artificialSplitZip.zip");
         final long splitSize = 64 * 1024L; /* 64 KB */
-        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
-            zipArchiveOutputStream.setUseZip64(Zip64Mode.Never);
+        try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+            outputStream.setUseZip64(Zip64Mode.Never);
             final ZipArchiveEntry ze1 = new ZipArchiveEntry("file01");
             ze1.setMethod(ZipEntry.STORED);
-            zipArchiveOutputStream.putArchiveEntry(ze1);
-            zipArchiveOutputStream.write(createArtificialData(65536));
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze1);
+            outputStream.write(createArtificialData(65536));
+            outputStream.closeArchiveEntry();
             final ZipArchiveEntry ze2 = new ZipArchiveEntry("file02");
             ze2.setMethod(ZipEntry.DEFLATED);
-            zipArchiveOutputStream.putArchiveEntry(ze2);
-            zipArchiveOutputStream.write(createArtificialData(65536));
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze2);
+            outputStream.write(createArtificialData(65536));
+            outputStream.closeArchiveEntry();
         }
 
         try (ZipFile zipFile = ZipFile.builder()
@@ -268,22 +248,22 @@ public final class ZipTest extends AbstractTest {
      * Tests split archive with 64-bit limit, both STORED and DEFLATED.
      */
     @Test
-    public void testBuildArtificialSplitZip64Test() throws IOException {
+    void testBuildArtificialSplitZip64Test() throws IOException {
         final File outputZipFile = newTempFile("artificialSplitZip.zip");
         final long splitSize = 64 * 1024L; /* 64 KB */
         final byte[] data = createArtificialData(128 * 1024);
-        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
-            zipArchiveOutputStream.setUseZip64(Zip64Mode.Always);
+        try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+            outputStream.setUseZip64(Zip64Mode.Always);
             final ZipArchiveEntry ze1 = new ZipArchiveEntry("file01");
             ze1.setMethod(ZipEntry.STORED);
-            zipArchiveOutputStream.putArchiveEntry(ze1);
-            zipArchiveOutputStream.write(data);
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze1);
+            outputStream.write(data);
+            outputStream.closeArchiveEntry();
             final ZipArchiveEntry ze2 = new ZipArchiveEntry("file02");
             ze2.setMethod(ZipEntry.DEFLATED);
-            zipArchiveOutputStream.putArchiveEntry(ze2);
-            zipArchiveOutputStream.write(data);
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze2);
+            outputStream.write(data);
+            outputStream.closeArchiveEntry();
         }
         try (ZipFile zipFile = ZipFile.builder().setPath(outputZipFile.toPath()).setMaxNumberOfDisks(Integer.MAX_VALUE).get()) {
             assertArrayEquals(data, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file01"))));
@@ -295,20 +275,20 @@ public final class ZipTest extends AbstractTest {
      * Tests split archive with 32-bit limit, with end of central directory skipping lack of space in segment.
      */
     @Test
-    public void testBuildSplitZip32_endOfCentralDirectorySkipBoundary() throws IOException {
+    void testBuildSplitZip32_endOfCentralDirectorySkipBoundary() throws IOException {
         final File outputZipFile = newTempFile("artificialSplitZip.zip");
         final long splitSize = 64 * 1024L; /* 64 KB */
         // 4 is PK signature, 36 is size of header + local file header,
         // 36 is length of central directory entry
         // 1 is remaining byte in first archive, this should be skipped
         final byte[] data1 = createArtificialData(64 * 1024 - 4 - 36 - 52 - 1);
-        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
-            zipArchiveOutputStream.setUseZip64(Zip64Mode.Never);
+        try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+            outputStream.setUseZip64(Zip64Mode.Never);
             final ZipArchiveEntry ze1 = new ZipArchiveEntry("file01");
             ze1.setMethod(ZipEntry.STORED);
-            zipArchiveOutputStream.putArchiveEntry(ze1);
-            zipArchiveOutputStream.write(data1);
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze1);
+            outputStream.write(data1);
+            outputStream.closeArchiveEntry();
         }
         assertEquals(64 * 1024L - 1, Files.size(outputZipFile.toPath().getParent().resolve("artificialSplitZip.z01")));
         try (ZipFile zipFile = ZipFile.builder().setPath(outputZipFile.toPath()).setMaxNumberOfDisks(Integer.MAX_VALUE).get()) {
@@ -320,7 +300,7 @@ public final class ZipTest extends AbstractTest {
      * Tests split archive with 32-bit limit, with file local headers crossing segment boundaries.
      */
     @Test
-    public void testBuildSplitZip32_metaCrossBoundary() throws IOException {
+    void testBuildSplitZip32_metaCrossBoundary() throws IOException {
         final File outputZipFile = newTempFile("artificialSplitZip.zip");
         final long splitSize = 64 * 1024L; /* 64 KB */
         // 4 is PK signature, 36 is size of header + local file header,
@@ -335,28 +315,28 @@ public final class ZipTest extends AbstractTest {
         // 13 is remaining size of third local file header
         // 1 is to wrap to next part
         final byte[] data4 = createArtificialData(64 * 1024 - 13 + 1);
-        try (ZipArchiveOutputStream zipArchiveOutputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
-            zipArchiveOutputStream.setUseZip64(Zip64Mode.Never);
+        try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(outputZipFile, splitSize)) {
+            outputStream.setUseZip64(Zip64Mode.Never);
             final ZipArchiveEntry ze1 = new ZipArchiveEntry("file01");
             ze1.setMethod(ZipEntry.STORED);
-            zipArchiveOutputStream.putArchiveEntry(ze1);
-            zipArchiveOutputStream.write(data1);
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze1);
+            outputStream.write(data1);
+            outputStream.closeArchiveEntry();
             final ZipArchiveEntry ze2 = new ZipArchiveEntry("file02");
             ze2.setMethod(ZipEntry.STORED);
-            zipArchiveOutputStream.putArchiveEntry(ze2);
-            zipArchiveOutputStream.write(data2);
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze2);
+            outputStream.write(data2);
+            outputStream.closeArchiveEntry();
             final ZipArchiveEntry ze3 = new ZipArchiveEntry("file03");
             ze3.setMethod(ZipEntry.STORED);
-            zipArchiveOutputStream.putArchiveEntry(ze3);
-            zipArchiveOutputStream.write(data3);
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze3);
+            outputStream.write(data3);
+            outputStream.closeArchiveEntry();
             final ZipArchiveEntry ze4 = new ZipArchiveEntry("file04");
             ze4.setMethod(ZipEntry.STORED);
-            zipArchiveOutputStream.putArchiveEntry(ze4);
-            zipArchiveOutputStream.write(data4);
-            zipArchiveOutputStream.closeArchiveEntry();
+            outputStream.putArchiveEntry(ze4);
+            outputStream.write(data4);
+            outputStream.closeArchiveEntry();
         }
         try (ZipFile zipFile = ZipFile.builder().setPath(outputZipFile.toPath()).setMaxNumberOfDisks(Integer.MAX_VALUE).get()) {
             assertArrayEquals(data1, IOUtils.toByteArray(zipFile.getInputStream(zipFile.getEntry("file01"))));
@@ -367,7 +347,7 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testBuildSplitZipTest() throws IOException {
+    void testBuildSplitZipTest() throws IOException {
         final File directoryToZip = getFilesToZip();
         createTestSplitZipSegments();
         final File lastFile = newTempFile("splitZip.zip");
@@ -392,7 +372,7 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testBuildSplitZipWithSegmentAlreadyExistThrowsException() throws IOException {
+    void testBuildSplitZipWithSegmentAlreadyExistThrowsException() throws IOException {
         final File directoryToZip = getFilesToZip();
         final File outputZipFile = newTempFile("splitZip.zip");
         final long splitSize = 100 * 1024L; /* 100 KB */
@@ -411,7 +391,7 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testBuildSplitZipWithTooLargeSizeThrowsException() throws IOException {
+    void testBuildSplitZipWithTooLargeSizeThrowsException() throws IOException {
         final Path file = Files.createTempFile("temp", "zip");
         try {
             assertThrows(IllegalArgumentException.class, () -> new ZipArchiveOutputStream(file, 4294967295L + 1));
@@ -421,13 +401,13 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testBuildSplitZipWithTooSmallSizeThrowsException() throws IOException {
+    void testBuildSplitZipWithTooSmallSizeThrowsException() throws IOException {
         createTempFile("temp", "zip").toPath();
         assertThrows(IllegalArgumentException.class, () -> new ZipArchiveOutputStream(createTempFile("temp", "zip"), 64 * 1024 - 1));
     }
 
     @Test
-    public void testCopyRawEntriesFromFile() throws IOException {
+    void testCopyRawEntriesFromFile() throws IOException {
         final File reference = createReferenceFile(Zip64Mode.Never, "expected.");
         final File file1 = createTempFile("src1.", ".zip");
         try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
@@ -454,7 +434,7 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testCopyRawZip64EntryFromFile() throws IOException {
+    void testCopyRawZip64EntryFromFile() throws IOException {
         final File reference = createTempFile("z64reference.", ".zip");
         try (ZipArchiveOutputStream zos1 = new ZipArchiveOutputStream(reference)) {
             zos1.setUseZip64(Zip64Mode.Always);
@@ -476,7 +456,7 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testDirectoryEntryFromFile() throws Exception {
+    void testDirectoryEntryFromFile() throws Exception {
         final File tmp = getTempDirFile();
         final File archive = createTempFile("test.", ".zip");
         final long beforeArchiveWrite;
@@ -498,7 +478,7 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testExplicitDirectoryEntry() throws Exception {
+    void testExplicitDirectoryEntry() throws Exception {
         final File archive = createTempFile("test.", ".zip");
         final long beforeArchiveWrite;
         try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(archive)) {
@@ -519,53 +499,43 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testExplicitFileEntry() throws Exception {
-        final File tmp = createTempFile();
+    void testExplicitFileEntry() throws Exception {
+        final File file = createTempFile();
         final File archive = createTempFile("test.", ".zip");
-        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(archive)) {
+        try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(archive)) {
             final ZipArchiveEntry in = new ZipArchiveEntry("foo");
-            in.setTime(tmp.lastModified());
-            in.setSize(tmp.length());
-            zos.putArchiveEntry(in);
-            final byte[] b = new byte[(int) tmp.length()];
-            try (InputStream fis = Files.newInputStream(tmp.toPath())) {
-                while (fis.read(b) > 0) {
-                    zos.write(b);
-                }
-            }
-            zos.closeArchiveEntry();
+            in.setTime(file.lastModified());
+            in.setSize(file.length());
+            outputStream.putArchiveEntry(in);
+            outputStream.write(file);
+            outputStream.closeArchiveEntry();
         }
         try (ZipFile zf = newZipFile(archive)) {
             final ZipArchiveEntry out = zf.getEntry("foo");
             assertNotNull(out);
             assertEquals("foo", out.getName());
-            assertEquals(tmp.length(), out.getSize());
-            assertEquals(tmp.lastModified() / 2000, out.getLastModifiedDate().getTime() / 2000);
+            assertEquals(file.length(), out.getSize());
+            assertEquals(file.lastModified() / 2000, out.getLastModifiedDate().getTime() / 2000);
             assertFalse(out.isDirectory());
         }
     }
 
     @Test
-    public void testFileEntryFromFile() throws Exception {
-        final File tmpFile = createTempFile();
+    void testFileEntryFromFile() throws Exception {
+        final File file = createTempFile();
         final File archive = createTempFile("test.", ".zip");
-        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(archive)) {
-            final ZipArchiveEntry in = new ZipArchiveEntry(tmpFile, "foo");
-            zos.putArchiveEntry(in);
-            final byte[] b = new byte[(int) tmpFile.length()];
-            try (InputStream fis = Files.newInputStream(tmpFile.toPath())) {
-                while (fis.read(b) > 0) {
-                    zos.write(b);
-                }
-            }
-            zos.closeArchiveEntry();
+        try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(archive)) {
+            final ZipArchiveEntry in = new ZipArchiveEntry(file, "foo");
+            outputStream.putArchiveEntry(in);
+            outputStream.write(file);
+            outputStream.closeArchiveEntry();
         }
         try (ZipFile zf = newZipFile(archive)) {
             final ZipArchiveEntry out = zf.getEntry("foo");
             assertNotNull(out);
             assertEquals("foo", out.getName());
-            assertEquals(tmpFile.length(), out.getSize());
-            assertEquals(tmpFile.lastModified() / 2000, out.getLastModifiedDate().getTime() / 2000);
+            assertEquals(file.length(), out.getSize());
+            assertEquals(file.lastModified() / 2000, out.getLastModifiedDate().getTime() / 2000);
             assertFalse(out.isDirectory());
         }
     }
@@ -576,19 +546,15 @@ public final class ZipTest extends AbstractTest {
         // stream access
         try (InputStream fis = Files.newInputStream(input.toPath());
                 ArchiveInputStream<?> in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", fis)) {
-            for (ArchiveEntry entry; (entry = in.getNextEntry()) != null;) {
-                readStream(in, entry, actualStatistics);
-            }
+            in.forEach(entry -> readStream(in, entry, actualStatistics));
         }
         // file access
-        try (ZipFile zf = newZipFile(input)) {
-            final Enumeration<ZipArchiveEntry> entries = zf.getEntries();
-            while (entries.hasMoreElements()) {
-                final ZipArchiveEntry zae = entries.nextElement();
-                try (InputStream in = zf.getInputStream(zae)) {
+        try (ZipFile zipFile = newZipFile(input)) {
+            zipFile.stream().forEach(zae -> {
+                try (InputStream in = zipFile.getInputStream(zae)) {
                     readStream(in, zae, actualStatistics);
                 }
-            }
+            });
         }
         // compare statistics of stream / file access
         for (final Map.Entry<String, List<List<Long>>> me : actualStatistics.entrySet()) {
@@ -600,28 +566,28 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testInputStreamStatisticsForBzip2Entry() throws IOException, ArchiveException {
+    void testInputStreamStatisticsForBzip2Entry() throws IOException, ArchiveException {
         final Map<String, List<Long>> expected = new HashMap<>();
         expected.put("lots-of-as", Arrays.asList(42L, 39L));
         testInputStreamStatistics("bzip2-zip.zip", expected);
     }
 
     @Test
-    public void testInputStreamStatisticsForDeflate64Entry() throws IOException, ArchiveException {
+    void testInputStreamStatisticsForDeflate64Entry() throws IOException, ArchiveException {
         final Map<String, List<Long>> expected = new HashMap<>();
         expected.put("input2", Arrays.asList(3072L, 2111L));
         testInputStreamStatistics("COMPRESS-380/COMPRESS-380.zip", expected);
     }
 
     @Test
-    public void testInputStreamStatisticsForImplodedEntry() throws IOException, ArchiveException {
+    void testInputStreamStatisticsForImplodedEntry() throws IOException, ArchiveException {
         final Map<String, List<Long>> expected = new HashMap<>();
         expected.put("LICENSE.TXT", Arrays.asList(11560L, 4131L));
         testInputStreamStatistics("imploding-8Kdict-3trees.zip", expected);
     }
 
     @Test
-    public void testInputStreamStatisticsForShrunkEntry() throws IOException, ArchiveException {
+    void testInputStreamStatisticsForShrunkEntry() throws IOException, ArchiveException {
         final Map<String, List<Long>> expected = new HashMap<>();
         expected.put("TEST1.XML", Arrays.asList(76L, 66L));
         expected.put("TEST2.XML", Arrays.asList(81L, 76L));
@@ -629,14 +595,14 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testInputStreamStatisticsForStoredEntry() throws IOException, ArchiveException {
+    void testInputStreamStatisticsForStoredEntry() throws IOException, ArchiveException {
         final Map<String, List<Long>> expected = new HashMap<>();
         expected.put("test.txt", Arrays.asList(5L, 5L));
         testInputStreamStatistics("COMPRESS-264.zip", expected);
     }
 
     @Test
-    public void testInputStreamStatisticsOfZipBombExcel() throws IOException, ArchiveException {
+    void testInputStreamStatisticsOfZipBombExcel() throws IOException, ArchiveException {
         final Map<String, List<Long>> expected = new HashMap<>();
         expected.put("[Content_Types].xml", Arrays.asList(8390036L, 8600L));
         expected.put("xl/worksheets/sheet1.xml", Arrays.asList(1348L, 508L));
@@ -651,7 +617,7 @@ public final class ZipTest extends AbstractTest {
      * @throws Exception
      */
     @Test
-    public void testListAllFilesWithNestedArchive() throws Exception {
+    void testListAllFilesWithNestedArchive() throws Exception {
         final File input = getFile("OSX_ArchiveWithNestedArchive.zip");
         final List<String> results = new ArrayList<>();
         final List<ZipException> expectedExceptions = new ArrayList<>();
@@ -683,10 +649,10 @@ public final class ZipTest extends AbstractTest {
     /**
      * Test case for being able to skip an entry in an {@link ZipArchiveInputStream} even if the compression method of that entry is unsupported.
      *
-     * @see <a href="https://issues.apache.org/jira/browse/COMPRESS-93" >COMPRESS-93</a>
+     * @see <a href="https://issues.apache.org/jira/browse/COMPRESS-93">COMPRESS-93</a>
      */
     @Test
-    public void testSkipEntryWithUnsupportedCompressionMethod() throws IOException {
+    void testSkipEntryWithUnsupportedCompressionMethod() throws IOException {
         try (ZipArchiveInputStream zip = new ZipArchiveInputStream(newInputStream("moby.zip"))) {
             final ZipArchiveEntry entry = zip.getNextZipEntry();
             assertEquals(ZipMethod.TOKENIZATION.getCode(), entry.getMethod(), "method");
@@ -697,10 +663,10 @@ public final class ZipTest extends AbstractTest {
     }
 
     /**
-     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-208" >COMPRESS-208</a>.
+     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-208">COMPRESS-208</a>.
      */
     @Test
-    public void testSkipsPK00Prefix() throws Exception {
+    void testSkipsPK00Prefix() throws Exception {
         final File input = getFile("COMPRESS-208.zip");
         final ArrayList<String> al = new ArrayList<>();
         al.add("test1.xml");
@@ -712,10 +678,10 @@ public final class ZipTest extends AbstractTest {
     }
 
     /**
-     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-93" >COMPRESS-93</a>.
+     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-93">COMPRESS-93</a>.
      */
     @Test
-    public void testTokenizationCompressionMethod() throws IOException {
+    void testTokenizationCompressionMethod() throws IOException {
         try (ZipFile moby = ZipFile.builder().setFile(getFile("moby.zip")).get()) {
             final ZipArchiveEntry entry = moby.getEntry("README");
             assertEquals(ZipMethod.TOKENIZATION.getCode(), entry.getMethod(), "method");
@@ -724,7 +690,7 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testUnixModeInAddRaw() throws IOException {
+    void testUnixModeInAddRaw() throws IOException {
         final File file1 = createTempFile("unixModeBits.", ".zip");
         try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
             final ZipArchiveEntry archiveEntry = new ZipArchiveEntry("fred");
@@ -740,13 +706,26 @@ public final class ZipTest extends AbstractTest {
         }
     }
 
+    @Test
+    void testUnsupportedCompressionMethodInAddRaw() throws IOException {
+        final File file1 = createTempFile("unsupportedCompressionMethod.", ".zip");
+        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(file1)) {
+            final ZipArchiveEntry archiveEntry = new ZipArchiveEntry("fred");
+            archiveEntry.setMethod(Integer.MAX_VALUE);
+            archiveEntry.setSize(3);
+            archiveEntry.setCompressedSize(3);
+            archiveEntry.setCrc(0);
+            zos.addRawArchiveEntry(archiveEntry, new ByteArrayInputStream("fud".getBytes()));
+        }
+    }
+
     /**
      * Archives 2 files and unarchives it again. If the file length of result and source is the same, it looks like the operations have worked
      *
      * @throws Exception
      */
     @Test
-    public void testZipArchiveCreation() throws Exception {
+    void testZipArchiveCreation() throws Exception {
         // Archive
         final File output = newTempFile("bla.zip");
         final File file1 = getFile("test1.xml");
@@ -755,11 +734,11 @@ public final class ZipTest extends AbstractTest {
             try (ArchiveOutputStream<ZipArchiveEntry> os = ArchiveStreamFactory.DEFAULT.createArchiveOutputStream("zip", out)) {
                 // entry 1
                 os.putArchiveEntry(new ZipArchiveEntry("testdata/test1.xml"));
-                Files.copy(file1.toPath(), os);
+                os.write(file1);
                 os.closeArchiveEntry();
                 // entry 2
                 os.putArchiveEntry(new ZipArchiveEntry("testdata/test2.xml"));
-                Files.copy(file2.toPath(), os);
+                os.write(file2);
                 os.closeArchiveEntry();
             }
         }
@@ -767,13 +746,12 @@ public final class ZipTest extends AbstractTest {
         final List<File> results = new ArrayList<>();
         try (InputStream fileInputStream = Files.newInputStream(output.toPath())) {
             try (ArchiveInputStream<ZipArchiveEntry> archiveInputStream = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", fileInputStream)) {
-                ZipArchiveEntry entry;
-                while ((entry = archiveInputStream.getNextEntry()) != null) {
+                archiveInputStream.forEach(entry -> {
                     final File outfile = new File(tempResultDir.getCanonicalPath() + "/result/" + entry.getName());
                     outfile.getParentFile().mkdirs();
                     Files.copy(archiveInputStream, outfile.toPath());
                     results.add(outfile);
-                }
+                });
             }
         }
         assertEquals(results.size(), 2);
@@ -789,7 +767,7 @@ public final class ZipTest extends AbstractTest {
      * @throws Exception
      */
     @Test
-    public void testZipArchiveCreationInMemory() throws Exception {
+    void testZipArchiveCreationInMemory() throws Exception {
         final byte[] file1Contents = readAllBytes("test1.xml");
         final byte[] file2Contents = readAllBytes("test2.xml");
         final List<byte[]> results = new ArrayList<>();
@@ -818,22 +796,17 @@ public final class ZipTest extends AbstractTest {
     }
 
     @Test
-    public void testZipArchiveEntryNewFromPath() throws Exception {
-        Path archivePath;
+    void testZipArchiveEntryNewFromPath() throws Exception {
+        final Path archivePath;
         final File tmpFile = createTempFile();
         final Path tmpFilePath = tmpFile.toPath();
         final File archiveFile = createTempFile("test.", ".zip");
         archivePath = archiveFile.toPath();
-        try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(archivePath)) {
-            final ZipArchiveEntry in = zos.createArchiveEntry(tmpFilePath, "foo");
-            zos.putArchiveEntry(in);
-            final byte[] b = new byte[(int) tmpFile.length()];
-            try (InputStream fis = Files.newInputStream(tmpFile.toPath())) {
-                while (fis.read(b) > 0) {
-                    zos.write(b);
-                }
-            }
-            zos.closeArchiveEntry();
+        try (ZipArchiveOutputStream outputStream = new ZipArchiveOutputStream(archivePath)) {
+            final ZipArchiveEntry in = outputStream.createArchiveEntry(tmpFilePath, "foo");
+            outputStream.putArchiveEntry(in);
+            outputStream.write(tmpFilePath);
+            outputStream.closeArchiveEntry();
         }
         try (ZipFile zf = newZipFile(archiveFile)) {
             final ZipArchiveEntry out = zf.getEntry("foo");
@@ -851,7 +824,7 @@ public final class ZipTest extends AbstractTest {
      * @throws Exception
      */
     @Test
-    public void testZipUnarchive() throws Exception {
+    void testZipUnarchive() throws Exception {
         final File input = getFile("bla.zip");
         try (InputStream is = Files.newInputStream(input.toPath());
                 ArchiveInputStream<ZipArchiveEntry> in = ArchiveStreamFactory.DEFAULT.createArchiveInputStream("zip", is)) {
