@@ -1,18 +1,20 @@
 /*
- *  Licensed to the Apache Software Foundation (ASF) under one or more
- *  contributor license agreements.  See the NOTICE file distributed with
- *  this work for additional information regarding copyright ownership.
- *  The ASF licenses this file to You under the Apache License, Version 2.0
- *  (the "License"); you may not use this file except in compliance with
- *  the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.commons.compress.archivers.sevenz;
 
@@ -57,8 +59,8 @@ import org.apache.commons.compress.utils.SeekableInMemoryByteChannel;
 import org.apache.commons.io.IOUtils;
 import org.junit.jupiter.api.Test;
 
-public class SevenZFileTest extends AbstractTest {
-    private static final String TEST2_CONTENT = "<?xml version = '1.0'?>\r\n<!DOCTYPE" + " connections>\r\n<meinxml>\r\n\t<leer />\r\n</meinxml>\n";
+class SevenZFileTest extends AbstractTest {
+    private static final String TEST2_CONTENT = "<?xml version = '1.0'?>\r\n<!DOCTYPE connections>\r\n<meinxml>\r\n\t<leer />\r\n</meinxml>\n";
 
     private static boolean isStrongCryptoAvailable() throws NoSuchAlgorithmException {
         return Cipher.getMaxAllowedKeyLength("AES/ECB/PKCS5Padding") >= 256;
@@ -95,7 +97,7 @@ public class SevenZFileTest extends AbstractTest {
             int off = 0;
             while (off < contents.length) {
                 final int bytesRead = sevenZFile.read(contents, off, contents.length - off);
-                assert bytesRead >= 0;
+                assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                 off += bytesRead;
             }
             assertEquals("Hello, world!\n", new String(contents, UTF_8));
@@ -123,7 +125,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void test7zDecryptUnarchive() throws Exception {
+    void test7zDecryptUnarchive() throws Exception {
         if (isStrongCryptoAvailable()) {
             test7zUnarchive(getFile("bla.encrypted.7z"), SevenZMethod.LZMA, // stack LZMA + AES
                     "foo".getBytes(UTF_16LE));
@@ -131,7 +133,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void test7zDecryptUnarchiveUsingCharArrayPassword() throws Exception {
+    void test7zDecryptUnarchiveUsingCharArrayPassword() throws Exception {
         if (isStrongCryptoAvailable()) {
             test7zUnarchive(getFile("bla.encrypted.7z"), SevenZMethod.LZMA, // stack LZMA + AES
                     "foo".toCharArray());
@@ -139,17 +141,17 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void test7zDeflate64Unarchive() throws Exception {
+    void test7zDeflate64Unarchive() throws Exception {
         test7zUnarchive(getFile("bla.deflate64.7z"), SevenZMethod.DEFLATE64);
     }
 
     @Test
-    public void test7zDeflateUnarchive() throws Exception {
+    void test7zDeflateUnarchive() throws Exception {
         test7zUnarchive(getFile("bla.deflate.7z"), SevenZMethod.DEFLATE);
     }
 
     @Test
-    public void test7zMultiVolumeUnarchive() throws Exception {
+    void test7zMultiVolumeUnarchive() throws Exception {
         try (@SuppressWarnings("deprecation")
         SevenZFile sevenZFile = new SevenZFile(MultiReadOnlySeekableByteChannel.forFiles(getFile("bla-multi.7z.001"), getFile("bla-multi.7z.002")))) {
             test7zUnarchive(sevenZFile, SevenZMethod.LZMA2);
@@ -161,7 +163,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void test7zUnarchive() throws Exception {
+    void test7zUnarchive() throws Exception {
         test7zUnarchive(getFile("bla.7z"), SevenZMethod.LZMA);
     }
 
@@ -211,7 +213,7 @@ public class SevenZFileTest extends AbstractTest {
         int off = 0;
         while (off < contents.length) {
             final int bytesRead = sevenZFile.read(contents, off, contents.length - off);
-            assert bytesRead >= 0;
+            assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
             off += bytesRead;
         }
         assertEquals(TEST2_CONTENT, new String(contents, UTF_8));
@@ -219,17 +221,17 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void test7zUnarchiveWithDefectHeader() throws Exception {
+    void test7zUnarchiveWithDefectHeader() throws Exception {
         test7zUnarchive(getFile("bla.noendheaderoffset.7z"), SevenZMethod.LZMA, true);
     }
 
     @Test
-    public void test7zUnarchiveWithDefectHeaderFailsByDefault() throws Exception {
+    void test7zUnarchiveWithDefectHeaderFailsByDefault() throws Exception {
         assertThrows(IOException.class, () -> test7zUnarchive(getFile("bla.noendheaderoffset.7z"), SevenZMethod.LZMA));
     }
 
     @Test
-    public void testAllEmptyFilesArchive() throws Exception {
+    void testAllEmptyFilesArchive() throws Exception {
         try (SevenZFile archive = getSevenZFile("7z-empty-mhc-off.7z")) {
             final SevenZArchiveEntry e = archive.getNextEntry();
             assertNotNull(e);
@@ -243,7 +245,7 @@ public class SevenZFileTest extends AbstractTest {
      * @see "https://issues.apache.org/jira/browse/COMPRESS-256"
      */
     @Test
-    public void testCompressedHeaderWithNonDefaultDictionarySize() throws Exception {
+    void testCompressedHeaderWithNonDefaultDictionarySize() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-256.7z")) {
             int count = 0;
             while (sevenZFile.getNextEntry() != null) {
@@ -254,7 +256,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testEncryptedArchiveRequiresPassword() throws Exception {
+    void testEncryptedArchiveRequiresPassword() throws Exception {
         final PasswordRequiredException ex = assertThrows(PasswordRequiredException.class, () -> getSevenZFile("bla.encrypted.7z").close(),
                 "shouldn't decrypt without a password");
         final String msg = ex.getMessage();
@@ -264,7 +266,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testExtractNonExistSpecifiedFile() throws Exception {
+    void testExtractNonExistSpecifiedFile() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-256.7z");
                 SevenZFile anotherSevenZFile = getSevenZFile("bla.7z")) {
             for (final SevenZArchiveEntry nonExistEntry : anotherSevenZFile.getEntries()) {
@@ -274,7 +276,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testExtractSpecifiedFile() throws Exception {
+    void testExtractSpecifiedFile() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-256.7z")) {
             final String testTxtContents = "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
                     + "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
@@ -288,7 +290,7 @@ public class SevenZFileTest extends AbstractTest {
                     final InputStream inputStream = sevenZFile.getInputStream(entry);
                     while (off < contents.length) {
                         final int bytesRead = inputStream.read(contents, off, contents.length - off);
-                        assert bytesRead >= 0;
+                        assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                         off += bytesRead;
                     }
                     assertEquals(testTxtContents, new String(contents, UTF_8));
@@ -299,7 +301,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testExtractSpecifiedFileDeprecated() throws Exception {
+    void testExtractSpecifiedFileDeprecated() throws Exception {
         try (@SuppressWarnings("deprecation")
         SevenZFile sevenZFile = new SevenZFile(getFile("COMPRESS-256.7z"))) {
             final String testTxtContents = "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
@@ -314,7 +316,7 @@ public class SevenZFileTest extends AbstractTest {
                     final InputStream inputStream = sevenZFile.getInputStream(entry);
                     while (off < contents.length) {
                         final int bytesRead = inputStream.read(contents, off, contents.length - off);
-                        assert bytesRead >= 0;
+                        assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                         off += bytesRead;
                     }
                     assertEquals(testTxtContents, new String(contents, UTF_8));
@@ -325,7 +327,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testGetDefaultName() throws Exception {
+    void testGetDefaultName() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("bla.deflate64.7z")) {
             assertEquals("bla.deflate64", sevenZFile.getDefaultName());
         }
@@ -347,7 +349,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testGetEntriesOfUnarchiveInMemoryTest() throws IOException {
+    void testGetEntriesOfUnarchiveInMemoryTest() throws IOException {
         final byte[] data = readAllBytes("bla.7z");
         try (SevenZFile sevenZFile = SevenZFile.builder().setSeekableByteChannel(new SeekableInMemoryByteChannel(data)).get()) {
             final Iterable<SevenZArchiveEntry> entries = sevenZFile.getEntries();
@@ -361,7 +363,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testGetEntriesOfUnarchiveTest() throws IOException {
+    void testGetEntriesOfUnarchiveTest() throws IOException {
         try (SevenZFile sevenZFile = getSevenZFile("bla.7z")) {
             final Iterable<SevenZArchiveEntry> entries = sevenZFile.getEntries();
             final Iterator<SevenZArchiveEntry> iter = entries.iterator();
@@ -374,7 +376,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testGivenNameWinsOverDefaultName() throws Exception {
+    void testGivenNameWinsOverDefaultName() throws Exception {
         try (@SuppressWarnings("deprecation")
         SevenZFile sevenZFile = new SevenZFile(getFile("bla.7z"), SevenZFileOptions.builder().withUseDefaultNameForUnnamedEntries(true).build())) {
             SevenZArchiveEntry ae = sevenZFile.getNextEntry();
@@ -400,9 +402,10 @@ public class SevenZFileTest extends AbstractTest {
      * @see <a href="https://issues.apache.org/jira/browse/COMPRESS-492">COMPRESS-492</a>
      */
     @Test
-    public void testHandlesEmptyArchiveWithFilesInfo() throws Exception {
+    void testHandlesEmptyArchiveWithFilesInfo() throws Exception {
         final File file = newTempFile("empty.7z");
         try (SevenZOutputFile s = new SevenZOutputFile(file)) {
+            // do nothing
         }
         try (SevenZFile z = SevenZFile.builder().setFile(file).get()) {
             assertFalse(z.getEntries().iterator().hasNext());
@@ -414,7 +417,7 @@ public class SevenZFileTest extends AbstractTest {
      * @see <a href="https://issues.apache.org/jira/browse/COMPRESS-492">COMPRESS-492</a>
      */
     @Test
-    public void testHandlesEmptyArchiveWithoutFilesInfo() throws Exception {
+    void testHandlesEmptyArchiveWithoutFilesInfo() throws Exception {
         try (SevenZFile z = getSevenZFile("COMPRESS-492.7z")) {
             assertFalse(z.getEntries().iterator().hasNext());
             assertNull(z.getNextEntry());
@@ -422,26 +425,31 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testHelloWorldHeaderCompressionOffCopy() throws Exception {
+    void testHelloWorldHeaderCompressionOffCopy() throws Exception {
         checkHelloWorld("7z-hello-mhc-off-copy.7z");
     }
 
     @Test
-    public void testHelloWorldHeaderCompressionOffLZMA2() throws Exception {
+    void testHelloWorldHeaderCompressionOffLZMA2() throws Exception {
         checkHelloWorld("7z-hello-mhc-off-lzma2.7z");
     }
 
     @Test
-    public void testLimitExtractionMemory() {
+    void testLimitExtractionMemory() {
         assertThrows(MemoryLimitException.class, () -> {
             try (SevenZFile sevenZFile = SevenZFile.builder().setFile(getFile("bla.7z")).setMaxMemoryLimitKb(1).get()) {
                 // Do nothing. Exception should be thrown
             }
         });
+        assertThrows(MemoryLimitException.class, () -> {
+            try (SevenZFile sevenZFile = SevenZFile.builder().setFile(getFile("bla.7z")).setMaxMemoryLimitKiB(1).get()) {
+                // Do nothing. Exception should be thrown
+            }
+        });
     }
 
     @Test
-    public void testNoNameCanBeReplacedByDefaultName() throws Exception {
+    void testNoNameCanBeReplacedByDefaultName() throws Exception {
         try (SevenZFile sevenZFile = SevenZFile.builder().setFile(getFile("bla-nonames.7z")).setUseDefaultNameForUnnamedEntries(true).get()) {
             SevenZArchiveEntry ae = sevenZFile.getNextEntry();
             assertNotNull(ae);
@@ -454,7 +462,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testNoNameMeansNoNameByDefault() throws Exception {
+    void testNoNameMeansNoNameByDefault() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("bla-nonames.7z")) {
             SevenZArchiveEntry ae = sevenZFile.getNextEntry();
             assertNotNull(ae);
@@ -467,19 +475,19 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testNoOOMOnCorruptedHeader() throws IOException {
+    void testNoOOMOnCorruptedHeader() throws IOException {
         final List<Path> testFiles = new ArrayList<>();
         testFiles.add(getPath("COMPRESS-542-1.7z"));
         testFiles.add(getPath("COMPRESS-542-2.7z"));
         testFiles.add(getPath("COMPRESS-542-endheadercorrupted.7z"));
         testFiles.add(getPath("COMPRESS-542-endheadercorrupted2.7z"));
-
         for (final Path file : testFiles) {
             {
                 final IOException e = assertThrows(IOException.class, () -> {
                     try (@SuppressWarnings("deprecation")
                     SevenZFile sevenZFile = new SevenZFile(Files.newByteChannel(file),
                             SevenZFileOptions.builder().withTryToRecoverBrokenArchives(true).build())) {
+                        // do nothing
                     }
                 }, "Expected IOException: start header corrupt and unable to guess end header");
                 assertEquals("Start header corrupt and unable to guess end header", e.getMessage());
@@ -488,6 +496,7 @@ public class SevenZFileTest extends AbstractTest {
                 final IOException e = assertThrows(IOException.class, () -> {
                     try (SevenZFile sevenZFile = SevenZFile.builder().setSeekableByteChannel(Files.newByteChannel(file)).setTryToRecoverBrokenArchives(true)
                             .get()) {
+                        // do nothing
                     }
                 }, "Expected IOException: start header corrupt and unable to guess end header");
                 assertEquals("Start header corrupt and unable to guess end header", e.getMessage());
@@ -496,7 +505,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testRandomAccessMultipleReadSameFile() throws Exception {
+    void testRandomAccessMultipleReadSameFile() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-256.7z")) {
             final String testTxtContents = "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
                     + "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
@@ -520,7 +529,7 @@ public class SevenZFileTest extends AbstractTest {
                     int off = 0;
                     while (off < contents.length) {
                         final int bytesRead = inputStream.read(contents, off, contents.length - off);
-                        assert bytesRead >= 0;
+                        assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                         off += bytesRead;
                     }
                     assertEquals(SevenZMethod.LZMA2, testTxtEntry.getContentMethods().iterator().next().getMethod());
@@ -531,7 +540,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testRandomAccessTogetherWithSequentialAccess() throws Exception {
+    void testRandomAccessTogetherWithSequentialAccess() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-256.7z")) {
             // @formatter:off
             final String testTxtContents = "111111111111111111111111111000101011\n"
@@ -562,7 +571,7 @@ public class SevenZFileTest extends AbstractTest {
             // just read them
             while (off < contents.length) {
                 final int bytesRead = sevenZFile.read(contents, off, contents.length - off);
-                assert bytesRead >= 0;
+                assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                 off += bytesRead;
             }
 
@@ -577,7 +586,7 @@ public class SevenZFileTest extends AbstractTest {
                     final InputStream inputStream = sevenZFile.getInputStream(entry);
                     while (off < contents.length) {
                         final int bytesRead = inputStream.read(contents, off, contents.length - off);
-                        assert bytesRead >= 0;
+                        assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                         off += bytesRead;
                     }
                     assertEquals(SevenZMethod.LZMA2, entry.getContentMethods().iterator().next().getMethod());
@@ -596,7 +605,7 @@ public class SevenZFileTest extends AbstractTest {
             off = 0;
             while (off < contents.length) {
                 final int bytesRead = sevenZFile.read(contents, off, contents.length - off);
-                assert bytesRead >= 0;
+                assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                 off += bytesRead;
             }
             assertEquals(SevenZMethod.LZMA2, nextEntry.getContentMethods().iterator().next().getMethod());
@@ -605,7 +614,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testRandomAccessWhenJumpingBackwards() throws Exception {
+    void testRandomAccessWhenJumpingBackwards() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-256.7z")) {
             final String testTxtContents = "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
                     + "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
@@ -627,7 +636,7 @@ public class SevenZFileTest extends AbstractTest {
             int off = 0;
             while (off < entryAfterTestTxtEntryContents.length) {
                 final int bytesRead = sevenZFile.read(entryAfterTestTxtEntryContents, off, entryAfterTestTxtEntryContents.length - off);
-                assert bytesRead >= 0;
+                assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                 off += bytesRead;
             }
 
@@ -638,7 +647,7 @@ public class SevenZFileTest extends AbstractTest {
                 off = 0;
                 while (off < contents.length) {
                     final int bytesRead = inputStream.read(contents, off, contents.length - off);
-                    assert bytesRead >= 0;
+                    assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                     off += bytesRead;
                 }
                 assertEquals(SevenZMethod.LZMA2, testTxtEntry.getContentMethods().iterator().next().getMethod());
@@ -651,7 +660,7 @@ public class SevenZFileTest extends AbstractTest {
             off = 0;
             while (off < nextTestContents.length) {
                 final int bytesRead = sevenZFile.read(nextTestContents, off, nextTestContents.length - off);
-                assert bytesRead >= 0;
+                assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                 off += bytesRead;
             }
 
@@ -662,7 +671,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testRandomAccessWhenJumpingForwards() throws Exception {
+    void testRandomAccessWhenJumpingForwards() throws Exception {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-256.7z")) {
             final String testTxtContents = "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
                     + "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n" + "111111111111111111111111111000101011\n"
@@ -697,7 +706,7 @@ public class SevenZFileTest extends AbstractTest {
                     int off = 0;
                     while (off < contents.length) {
                         final int bytesRead = inputStream.read(contents, off, contents.length - off);
-                        assert bytesRead >= 0;
+                        assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
                         off += bytesRead;
                     }
                     assertEquals(SevenZMethod.LZMA2, testTxtEntry.getContentMethods().iterator().next().getMethod());
@@ -709,7 +718,7 @@ public class SevenZFileTest extends AbstractTest {
 
     // https://issues.apache.org/jira/browse/COMPRESS-320
     @Test
-    public void testRandomlySkippingEntries() throws Exception {
+    void testRandomlySkippingEntries() throws Exception {
         // Read sequential reference.
         final Map<String, byte[]> entriesByName = new HashMap<>();
         try (SevenZFile archive = getSevenZFile("COMPRESS-320/Copy.7z")) {
@@ -752,7 +761,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testReadBigSevenZipFile() throws IOException {
+    void testReadBigSevenZipFile() throws IOException {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-592.7z")) {
             SevenZArchiveEntry entry = sevenZFile.getNextEntry();
             while (entry != null) {
@@ -769,7 +778,7 @@ public class SevenZFileTest extends AbstractTest {
      * @see "https://issues.apache.org/jira/browse/COMPRESS-348"
      */
     @Test
-    public void testReadEntriesOfSize0() throws IOException {
+    void testReadEntriesOfSize0() throws IOException {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-348.7z")) {
             int entries = 0;
             SevenZArchiveEntry entry = sevenZFile.getNextEntry();
@@ -787,8 +796,30 @@ public class SevenZFileTest extends AbstractTest {
         }
     }
 
+    /**
+     * Test case for <a href="https://issues.apache.org/jira/browse/COMPRESS-681">COMPRESS-681</a>.
+     */
     @Test
-    public void testReadingBackDeltaDistance() throws Exception {
+    void testReadingArchiveProperties() throws IOException {
+        final String entryName = "COMPRESS-681.txt";
+        final String entryContent = "https://issues.apache.org/jira/browse/COMPRESS-681";
+        try (SevenZFile archive = getSevenZFile("COMPRESS-681.7z")) {
+            final SevenZArchiveEntry entry = archive.getNextEntry();
+            assertEquals(entryName, entry.getName());
+            final byte[] contents = new byte[(int) entry.getSize()];
+            int off = 0;
+            while (off < contents.length) {
+                final int bytesRead = archive.read(contents, off, contents.length - off);
+                assertTrue(bytesRead >= 0, "bytesRead exp: >=0, act: " + bytesRead);
+                off += bytesRead;
+            }
+            assertEquals(entryContent, new String(contents, UTF_8));
+            assertNull(archive.getNextEntry());
+        }
+    }
+
+    @Test
+    void testReadingBackDeltaDistance() throws Exception {
         final File output = newTempFile("delta-distance.7z");
         try (SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
             outArchive.setContentMethods(
@@ -809,7 +840,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testReadingBackLZMA2DictSize() throws Exception {
+    void testReadingBackLZMA2DictSize() throws Exception {
         final File output = newTempFile("lzma2-dictsize.7z");
         try (SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
             outArchive.setContentMethods(Arrays.asList(new SevenZMethodConfiguration(SevenZMethod.LZMA2, 1 << 20)));
@@ -829,7 +860,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testReadTimesFromFile() throws IOException {
+    void testReadTimesFromFile() throws IOException {
         try (SevenZFile sevenZFile = getSevenZFile("times.7z")) {
             SevenZArchiveEntry entry = sevenZFile.getNextEntry();
             assertNotNull(entry);
@@ -855,7 +886,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testRetrieveInputStreamForAllEntriesMultipleTimes() throws IOException {
+    void testRetrieveInputStreamForAllEntriesMultipleTimes() throws IOException {
         try (SevenZFile sevenZFile = getSevenZFile("bla.7z")) {
             for (final SevenZArchiveEntry entry : sevenZFile.getEntries()) {
                 final byte[] firstRead = read(sevenZFile, entry);
@@ -866,7 +897,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testRetrieveInputStreamForAllEntriesWithoutCRCMultipleTimes() throws IOException {
+    void testRetrieveInputStreamForAllEntriesWithoutCRCMultipleTimes() throws IOException {
         try (SevenZOutputFile out = new SevenZOutputFile(newTempFile("test.7z"))) {
             final Path inputFile = Files.createTempFile("SevenZTestTemp", "");
 
@@ -888,7 +919,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testRetrieveInputStreamForShuffledEntries() throws IOException {
+    void testRetrieveInputStreamForShuffledEntries() throws IOException {
         try (SevenZFile sevenZFile = getSevenZFile("COMPRESS-348.7z")) {
             final List<SevenZArchiveEntry> entries = (List<SevenZArchiveEntry>) sevenZFile.getEntries();
             Collections.shuffle(entries);
@@ -899,7 +930,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testSevenZWithEOS() throws IOException {
+    void testSevenZWithEOS() throws IOException {
         try (SevenZFile sevenZFile = getSevenZFile("lzma-with-eos.7z")) {
             final List<SevenZArchiveEntry> entries = (List<SevenZArchiveEntry>) sevenZFile.getEntries();
             for (final SevenZArchiveEntry entry : entries) {
@@ -909,7 +940,7 @@ public class SevenZFileTest extends AbstractTest {
     }
 
     @Test
-    public void testSignatureCheck() {
+    void testSignatureCheck() {
         assertTrue(SevenZFile.matches(SevenZFile.sevenZSignature, SevenZFile.sevenZSignature.length));
         assertTrue(SevenZFile.matches(SevenZFile.sevenZSignature, SevenZFile.sevenZSignature.length + 1));
         assertFalse(SevenZFile.matches(SevenZFile.sevenZSignature, SevenZFile.sevenZSignature.length - 1));
