@@ -1,18 +1,20 @@
 /*
- *  Licensed to the Apache Software Foundation (ASF) under one or more
- *  contributor license agreements.  See the NOTICE file distributed with
- *  this work for additional information regarding copyright ownership.
- *  The ASF licenses this file to You under the Apache License, Version 2.0
- *  (the "License"); you may not use this file except in compliance with
- *  the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- *  Unless required by applicable law or agreed to in writing, software
- *  distributed under the License is distributed on an "AS IS" BASIS,
- *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- *  See the License for the specific language governing permissions and
- *  limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.commons.compress.archivers.sevenz;
 
@@ -21,6 +23,7 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -42,11 +45,11 @@ import org.apache.commons.compress.AbstractTest;
 import org.apache.commons.compress.PasswordRequiredException;
 import org.apache.commons.compress.utils.ByteUtils;
 import org.apache.commons.compress.utils.SeekableInMemoryByteChannel;
-import org.apache.commons.compress.utils.TimeUtils;
+import org.apache.commons.compress.utils.TimeUtilsTest;
 import org.junit.jupiter.api.Test;
 import org.tukaani.xz.LZMA2Options;
 
-public class SevenZOutputFileTest extends AbstractTest {
+class SevenZOutputFileTest extends AbstractTest {
 
     private static final boolean XZ_BCJ_IS_BUGGY;
 
@@ -131,11 +134,11 @@ public class SevenZOutputFileTest extends AbstractTest {
         final FileTime fileTime = FileTime.from(Instant.ofEpochSecond(now.getEpochSecond(), now.getNano() + 999900));
         // However, in some platforms, Java's Instant has a precision of nanoseconds.
         // Truncate the resulting FileTime to 100ns intervals.
-        return TimeUtils.truncateToHundredNanos(fileTime);
+        return TimeUtilsTest.truncateToHundredNanos(fileTime);
     }
 
     @Test
-    public void testArchiveWithMixedMethods() throws Exception {
+    void testArchiveWithMixedMethods() throws Exception {
         final File output = newTempFile("mixed-methods.7z");
         try (SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
             addFile(outArchive, 0, true);
@@ -149,7 +152,7 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testBCJARMRoundtrip() throws Exception {
+    void testBCJARMRoundtrip() throws Exception {
         if (XZ_BCJ_IS_BUGGY) {
             return;
         }
@@ -157,7 +160,7 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testBCJARMThumbRoundtrip() throws Exception {
+    void testBCJARMThumbRoundtrip() throws Exception {
         if (XZ_BCJ_IS_BUGGY) {
             return;
         }
@@ -165,7 +168,7 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testBCJIA64Roundtrip() throws Exception {
+    void testBCJIA64Roundtrip() throws Exception {
         if (XZ_BCJ_IS_BUGGY) {
             return;
         }
@@ -173,7 +176,7 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testBCJPPCRoundtrip() throws Exception {
+    void testBCJPPCRoundtrip() throws Exception {
         if (XZ_BCJ_IS_BUGGY) {
             return;
         }
@@ -181,7 +184,7 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testBCJSparcRoundtrip() throws Exception {
+    void testBCJSparcRoundtrip() throws Exception {
         if (XZ_BCJ_IS_BUGGY) {
             return;
         }
@@ -189,7 +192,7 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testBCJX86Roundtrip() throws Exception {
+    void testBCJX86Roundtrip() throws Exception {
         if (XZ_BCJ_IS_BUGGY) {
             return;
         }
@@ -197,19 +200,19 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testBzip2Roundtrip() throws Exception {
+    void testBzip2Roundtrip() throws Exception {
         testRoundTrip(SevenZMethod.BZIP2);
     }
 
     @Test
-    public void testBzip2WithConfiguration() throws Exception {
+    void testBzip2WithConfiguration() throws Exception {
         final File output = newTempFile("bzip2-options.7z");
         // 400k block size
         createAndReadBack(output, Collections.singletonList(new SevenZMethodConfiguration(SevenZMethod.BZIP2, 4)));
     }
 
     @Test
-    public void testCantFinishTwice() throws IOException {
+    void testCantFinishTwice() throws IOException {
         final File output = newTempFile("finish.7z");
         try (SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
             outArchive.finish();
@@ -232,29 +235,29 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testCopyRoundtrip() throws Exception {
+    void testCopyRoundtrip() throws Exception {
         testRoundTrip(SevenZMethod.COPY);
     }
 
     @Test
-    public void testDeflateRoundtrip() throws Exception {
+    void testDeflateRoundtrip() throws Exception {
         testRoundTrip(SevenZMethod.DEFLATE);
     }
 
     @Test
-    public void testDeflateWithConfiguration() throws Exception {
+    void testDeflateWithConfiguration() throws Exception {
         final File output = newTempFile("deflate-options.7z");
         // Deflater.BEST_SPEED
         createAndReadBack(output, Collections.singletonList(new SevenZMethodConfiguration(SevenZMethod.DEFLATE, 1)));
     }
 
     @Test
-    public void testDeltaRoundtrip() throws Exception {
+    void testDeltaRoundtrip() throws Exception {
         testFilterRoundTrip(new SevenZMethodConfiguration(SevenZMethod.DELTA_FILTER));
     }
 
     @Test
-    public void testDirectoriesAndEmptyFiles() throws Exception {
+    void testDirectoriesAndEmptyFiles() throws Exception {
         final File output = newTempFile("empties.7z");
 
         final FileTime accessTime = getHundredNanosFileTime();
@@ -338,13 +341,13 @@ public class SevenZOutputFileTest extends AbstractTest {
 
         try (SevenZFile archive = SevenZFile.builder().setFile(output).get()) {
             SevenZArchiveEntry entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/", entry.getName());
             assertTrue(entry.isDirectory());
             assertFalse(entry.isAntiItem());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -355,7 +358,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar/boo0", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -366,7 +369,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar/boo1", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -377,7 +380,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar/boo10000", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -388,7 +391,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("foo/bar/test.txt", entry.getName());
             assertFalse(entry.isDirectory());
             assertFalse(entry.isAntiItem());
@@ -399,7 +402,7 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(creationDate, entry.getCreationDate());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("xyzzy", entry.getName());
             assertEquals(1, entry.getSize());
             assertFalse(entry.getHasAccessDate());
@@ -407,19 +410,19 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(0, archive.read());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("baz/", entry.getName());
             assertTrue(entry.isDirectory());
             assertTrue(entry.isAntiItem());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("baz2/", entry.getName());
             assertTrue(entry.isDirectory());
             assertTrue(entry.isAntiItem());
 
             entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "Entry should not be null");
             assertEquals("dada", entry.getName());
             assertEquals(2, entry.getSize());
             final byte[] content = new byte[2];
@@ -428,13 +431,13 @@ public class SevenZOutputFileTest extends AbstractTest {
             assertEquals(42, content[1]);
             assertEquals(17, entry.getWindowsAttributes());
 
-            assert archive.getNextEntry() == null;
+            assertNull(archive.getNextEntry(), "getNextEntry should return null");
         }
 
     }
 
     @Test
-    public void testDirectoriesOnly() throws Exception {
+    void testDirectoriesOnly() throws Exception {
         final File output = newTempFile("dirs.7z");
         try (SevenZOutputFile outArchive = new SevenZOutputFile(output)) {
             final SevenZArchiveEntry entry = new SevenZArchiveEntry();
@@ -446,23 +449,23 @@ public class SevenZOutputFileTest extends AbstractTest {
 
         try (SevenZFile archive = SevenZFile.builder().setFile(output).get()) {
             final SevenZArchiveEntry entry = archive.getNextEntry();
-            assert entry != null;
+            assertNotNull(entry, "entry should not be null");
             assertEquals("foo/", entry.getName());
             assertTrue(entry.isDirectory());
             assertFalse(entry.isAntiItem());
 
-            assert archive.getNextEntry() == null;
+            assertNull(archive.getNextEntry(), "getnextEntry should return null");
         }
 
     }
 
     @Test
-    public void testEightEmptyFiles() throws Exception {
+    void testEightEmptyFiles() throws Exception {
         testCompress252(8, 0);
     }
 
     @Test
-    public void testEightFilesSomeNotEmpty() throws Exception {
+    void testEightFilesSomeNotEmpty() throws Exception {
         testCompress252(8, 2);
     }
 
@@ -475,7 +478,7 @@ public class SevenZOutputFileTest extends AbstractTest {
      * </p>
      */
     @Test
-    public void testEncrypt() throws Exception {
+    void testEncrypt() throws Exception {
         final File output = newTempFile("encrypted.7z");
         try (SevenZOutputFile outArchive = new SevenZOutputFile(output, "foo".toCharArray())) {
             addFile(outArchive, 0, 1, null);
@@ -509,45 +512,45 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testLzma2Roundtrip() throws Exception {
+    void testLzma2Roundtrip() throws Exception {
         testRoundTrip(SevenZMethod.LZMA2);
     }
 
     @Test
-    public void testLzma2WithIntConfiguration() throws Exception {
+    void testLzma2WithIntConfiguration() throws Exception {
         final File output = newTempFile("lzma2-options.7z");
         // 1 MB dictionary
         createAndReadBack(output, Collections.singletonList(new SevenZMethodConfiguration(SevenZMethod.LZMA2, 1 << 20)));
     }
 
     @Test
-    public void testLzma2WithOptionsConfiguration() throws Exception {
+    void testLzma2WithOptionsConfiguration() throws Exception {
         final File output = newTempFile("lzma2-options2.7z");
         final LZMA2Options opts = new LZMA2Options(1);
         createAndReadBack(output, Collections.singletonList(new SevenZMethodConfiguration(SevenZMethod.LZMA2, opts)));
     }
 
     @Test
-    public void testLzmaWithIntConfiguration() throws Exception {
+    void testLzmaWithIntConfiguration() throws Exception {
         final File output = newTempFile("lzma-options.7z");
         // 1 MB dictionary
         createAndReadBack(output, Collections.singletonList(new SevenZMethodConfiguration(SevenZMethod.LZMA, 1 << 20)));
     }
 
     @Test
-    public void testLzmaWithOptionsConfiguration() throws Exception {
+    void testLzmaWithOptionsConfiguration() throws Exception {
         final File output = newTempFile("lzma-options2.7z");
         final LZMA2Options opts = new LZMA2Options(1);
         createAndReadBack(output, Collections.singletonList(new SevenZMethodConfiguration(SevenZMethod.LZMA, opts)));
     }
 
     @Test
-    public void testNineEmptyFiles() throws Exception {
+    void testNineEmptyFiles() throws Exception {
         testCompress252(9, 0);
     }
 
     @Test
-    public void testNineFilesSomeNotEmpty() throws Exception {
+    void testNineFilesSomeNotEmpty() throws Exception {
         testCompress252(9, 2);
     }
 
@@ -559,27 +562,27 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testSevenEmptyFiles() throws Exception {
+    void testSevenEmptyFiles() throws Exception {
         testCompress252(7, 0);
     }
 
     @Test
-    public void testSevenFilesSomeNotEmpty() throws Exception {
+    void testSevenFilesSomeNotEmpty() throws Exception {
         testCompress252(7, 2);
     }
 
     @Test
-    public void testSixEmptyFiles() throws Exception {
+    void testSixEmptyFiles() throws Exception {
         testCompress252(6, 0);
     }
 
     @Test
-    public void testSixFilesSomeNotEmpty() throws Exception {
+    void testSixFilesSomeNotEmpty() throws Exception {
         testCompress252(6, 2);
     }
 
     @Test
-    public void testStackOfContentCompressions() throws Exception {
+    void testStackOfContentCompressions() throws Exception {
         final File output = newTempFile("multiple-methods.7z");
         final ArrayList<SevenZMethodConfiguration> methods = new ArrayList<>();
         methods.add(new SevenZMethodConfiguration(SevenZMethod.LZMA2));
@@ -590,7 +593,7 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testStackOfContentCompressionsInMemory() throws Exception {
+    void testStackOfContentCompressionsInMemory() throws Exception {
         final ArrayList<SevenZMethodConfiguration> methods = new ArrayList<>();
         methods.add(new SevenZMethodConfiguration(SevenZMethod.LZMA2));
         methods.add(new SevenZMethodConfiguration(SevenZMethod.COPY));
@@ -602,12 +605,12 @@ public class SevenZOutputFileTest extends AbstractTest {
     }
 
     @Test
-    public void testTwentyNineEmptyFiles() throws Exception {
+    void testTwentyNineEmptyFiles() throws Exception {
         testCompress252(29, 0);
     }
 
     @Test
-    public void testTwentyNineFilesSomeNotEmpty() throws Exception {
+    void testTwentyNineFilesSomeNotEmpty() throws Exception {
         testCompress252(29, 7);
     }
 
