@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -30,7 +30,7 @@ import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.Arguments;
 import org.junit.jupiter.params.provider.MethodSource;
 
-public class CompressorStreamFactoryRoundtripTest {
+class CompressorStreamFactoryRoundtripTest {
 
     public static Stream<Arguments> data() {
         // @formatter:off
@@ -50,12 +50,12 @@ public class CompressorStreamFactoryRoundtripTest {
 
     @ParameterizedTest
     @MethodSource("data")
-    public void testCompressorStreamFactoryRoundtrip(final String compressorName) throws Exception {
+    void testCompressorStreamFactoryRoundtrip(final String compressorName) throws Exception {
         final CompressorStreamProvider factory = new CompressorStreamFactory();
         final ByteArrayOutputStream compressedOs = new ByteArrayOutputStream();
         final String fixture = "The quick brown fox jumps over the lazy dog";
-        try (CompressorOutputStream compressorOutputStream = factory.createCompressorOutputStream(compressorName, compressedOs)) {
-            compressorOutputStream.write(fixture.getBytes(StandardCharsets.UTF_8.name()));
+        try (CompressorOutputStream<?> compressorOutputStream = factory.createCompressorOutputStream(compressorName, compressedOs)) {
+            compressorOutputStream.writeUtf8(fixture);
             compressorOutputStream.flush();
         }
         final ByteArrayInputStream is = new ByteArrayInputStream(compressedOs.toByteArray());
