@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -36,22 +36,22 @@ import org.junit.jupiter.api.Test;
 public final class FramedSnappyTest extends AbstractTest {
 
     @Test
-    public void testDefaultExtraction() throws Exception {
+    void testDefaultExtraction() throws Exception {
         testUnarchive(FramedSnappyCompressorInputStream::new);
     }
 
     @Test
-    public void testDefaultExtractionViaFactory() throws Exception {
+    void testDefaultExtractionViaFactory() throws Exception {
         testUnarchive(is -> new CompressorStreamFactory().createCompressorInputStream(CompressorStreamFactory.SNAPPY_FRAMED, is));
     }
 
     @Test
-    public void testDefaultExtractionViaFactoryAutodetection() throws Exception {
+    void testDefaultExtractionViaFactoryAutodetection() throws Exception {
         testUnarchive(is -> new CompressorStreamFactory().createCompressorInputStream(is));
     }
 
     @Test
-    public void testRoundtrip() throws Exception {
+    void testRoundtrip() throws Exception {
         testRoundtrip(getFile("test.txt"));
         testRoundtrip(getFile("bla.tar"));
         testRoundtrip(getFile("COMPRESS-256.7z"));
@@ -60,8 +60,8 @@ public final class FramedSnappyTest extends AbstractTest {
     private void testRoundtrip(final File input) throws Exception {
         final File outputSz = newTempFile(input.getName() + ".sz");
         try (OutputStream os = Files.newOutputStream(outputSz.toPath());
-                CompressorOutputStream sos = new CompressorStreamFactory().createCompressorOutputStream("snappy-framed", os)) {
-            Files.copy(input.toPath(), sos);
+                CompressorOutputStream<?> sos = new CompressorStreamFactory().createCompressorOutputStream("snappy-framed", os)) {
+            sos.write(input);
         }
         try (InputStream is = Files.newInputStream(input.toPath());
                 CompressorInputStream sis = new CompressorStreamFactory().createCompressorInputStream("snappy-framed",
@@ -73,7 +73,7 @@ public final class FramedSnappyTest extends AbstractTest {
     }
 
     @Test
-    public void testRoundtripWithOneBigWrite() throws Exception {
+    void testRoundtripWithOneBigWrite() throws Exception {
         final Random r = new Random();
         final File input = newTempFile("bigChunkTest");
         try (OutputStream fs = Files.newOutputStream(input.toPath())) {
@@ -84,7 +84,7 @@ public final class FramedSnappyTest extends AbstractTest {
         final File outputSz = newTempFile(input.getName() + ".sz");
         try (InputStream is = Files.newInputStream(input.toPath());
                 OutputStream os = Files.newOutputStream(outputSz.toPath());
-                CompressorOutputStream sos = new CompressorStreamFactory().createCompressorOutputStream("snappy-framed", os)) {
+                CompressorOutputStream<?> sos = new CompressorStreamFactory().createCompressorOutputStream("snappy-framed", os)) {
             final byte[] b = IOUtils.toByteArray(is);
             sos.write(b[0]);
             sos.write(b, 1, b.length - 1); // must be split into multiple compressed chunks
