@@ -7,7 +7,7 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -20,11 +20,8 @@ package org.apache.commons.compress.compressors;
 
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
-import static org.junit.jupiter.api.Assertions.fail;
 
-import java.io.BufferedInputStream;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
@@ -32,22 +29,11 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.file.Files;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Objects;
-import java.util.concurrent.ExecutionException;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
-import java.util.concurrent.Future;
-import java.util.stream.Collectors;
-import java.util.stream.IntStream;
+import java.time.Instant;
 import java.util.zip.Deflater;
 import java.util.zip.GZIPInputStream;
 
 import org.apache.commons.compress.AbstractTest;
-import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
-import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
-import org.apache.commons.compress.archivers.tar.TarConstants;
 import org.apache.commons.compress.compressors.gzip.GzipCompressorInputStream;
 import org.apache.commons.compress.compressors.gzip.GzipCompressorOutputStream;
 import org.apache.commons.compress.compressors.gzip.GzipParameters;
@@ -58,65 +44,11 @@ import org.junit.jupiter.params.provider.ValueSource;
 
 public final class GZipTest extends AbstractTest {
 
-    private void testCompress666(final int factor, final boolean bufferInputStream, final String localPath) throws ExecutionException, InterruptedException {
-        final ExecutorService executorService = Executors.newFixedThreadPool(10);
-        try {
-            final List<Future<?>> tasks = IntStream.range(0, 200).mapToObj(index -> executorService.submit(() -> {
-                TarArchiveEntry tarEntry = null;
-                try (InputStream inputStream = getClass().getResourceAsStream(localPath);
-                        TarArchiveInputStream tarInputStream = new TarArchiveInputStream(
-                                bufferInputStream ? new BufferedInputStream(new GZIPInputStream(inputStream)) : new GZIPInputStream(inputStream),
-                                TarConstants.DEFAULT_RCDSIZE * factor, TarConstants.DEFAULT_RCDSIZE)) {
-                    while ((tarEntry = tarInputStream.getNextEntry()) != null) {
-                        assertNotNull(tarEntry);
-                    }
-                } catch (final IOException e) {
-                    fail(Objects.toString(tarEntry), e);
-                }
-            })).collect(Collectors.toList());
-            final List<Exception> list = new ArrayList<>();
-            for (final Future<?> future : tasks) {
-                try {
-                    future.get();
-                } catch (final Exception e) {
-                    list.add(e);
-                }
-            }
-            // check:
-            if (!list.isEmpty()) {
-                fail(list.get(0));
-            }
-            // or:
-            // assertTrue(list.isEmpty(), () -> list.size() + " exceptions: " + list.toString());
-        } finally {
-            executorService.shutdownNow();
-        }
-    }
-
-    /**
-     * Tests https://issues.apache.org/jira/browse/COMPRESS-666
-     *
-     * A factor of 20 is the default.
-     */
-    @ParameterizedTest
-    @ValueSource(ints = { 1, 2, 4, 8, 16, 20, 32, 64, 128 })
-    public void testCompress666Buffered(final int factor) throws ExecutionException, InterruptedException {
-        testCompress666(factor, true, "/COMPRESS-666/compress-666.tar.gz");
-    }
-
-    /**
-     * Tests https://issues.apache.org/jira/browse/COMPRESS-666
-     *
-     * A factor of 20 is the default.
-     */
-    @ParameterizedTest
-    @ValueSource(ints = { 1, 2, 4, 8, 16, 20, 32, 64, 128 })
-    public void testCompress666Unbuffered(final int factor) throws ExecutionException, InterruptedException {
-        testCompress666(factor, false, "/COMPRESS-666/compress-666.tar.gz");
-    }
+    private static final int MTIME = 123456000;
+    private static final Instant MTIME_INSTANT = Instant.ofEpochSecond(MTIME);
 
     @Test
-    public void testConcatenatedStreamsReadFirstOnly() throws Exception {
+    void testConcatenatedStreamsReadFirstOnly() throws Exception {
         final File input = getFile("multiple.gz");
         try (InputStream is = Files.newInputStream(input.toPath())) {
             try (CompressorInputStream in = new CompressorStreamFactory().createCompressorInputStream("gz", is)) {
@@ -127,7 +59,7 @@ public final class GZipTest extends AbstractTest {
     }
 
     @Test
-    public void testConcatenatedStreamsReadFully() throws Exception {
+    void testConcatenatedStreamsReadFully() throws Exception {
         final File input = getFile("multiple.gz");
         try (InputStream is = Files.newInputStream(input.toPath())) {
             try (CompressorInputStream in = new GzipCompressorInputStream(is, true)) {
@@ -143,7 +75,7 @@ public final class GZipTest extends AbstractTest {
      * @see "https://issues.apache.org/jira/browse/COMPRESS-84"
      */
     @Test
-    public void testCorruptedInput() throws Exception {
+    void testCorruptedInput() throws Exception {
         final byte[] data = readAllBytes("bla.tgz");
         try (InputStream in = new ByteArrayInputStream(data, 0, data.length - 1);
                 CompressorInputStream cin = new CompressorStreamFactory().createCompressorInputStream("gz", in);
@@ -169,33 +101,33 @@ public final class GZipTest extends AbstractTest {
     }
 
     @Test
-    public void testExtraFlagsBestCompression() throws Exception {
+    void testExtraFlagsBestCompression() throws Exception {
         testExtraFlags(Deflater.BEST_COMPRESSION, 2, 1024);
     }
 
     @Test
-    public void testExtraFlagsDefaultCompression() throws Exception {
+    void testExtraFlagsDefaultCompression() throws Exception {
         testExtraFlags(Deflater.DEFAULT_COMPRESSION, 0, 4096);
     }
 
     @Test
-    public void testExtraFlagsFastestCompression() throws Exception {
+    void testExtraFlagsFastestCompression() throws Exception {
         testExtraFlags(Deflater.BEST_SPEED, 4, 128);
     }
 
     @Test
-    public void testGzipCreation() throws Exception {
+    void testGzipCreation() throws Exception {
         final File input = getFile("test1.xml");
         final File output = newTempFile("test1.xml.gz");
         try (OutputStream out = Files.newOutputStream(output.toPath())) {
-            try (CompressorOutputStream cos = new CompressorStreamFactory().createCompressorOutputStream("gz", out)) {
-                Files.copy(input.toPath(), cos);
+            try (CompressorOutputStream<?> cos = new CompressorStreamFactory().createCompressorOutputStream("gz", out)) {
+                cos.write(input);
             }
         }
     }
 
     @Test
-    public void testGzipUnarchive() throws Exception {
+    void testGzipUnarchive() throws Exception {
         final File input = getFile("bla.tgz");
         final File output = newTempFile("bla.tar");
         try (InputStream is = Files.newInputStream(input.toPath())) {
@@ -206,7 +138,7 @@ public final class GZipTest extends AbstractTest {
     }
 
     @Test
-    public void testInteroperabilityWithGzipCompressorInputStream() throws Exception {
+    void testInteroperabilityWithGzipCompressorInputStream() throws Exception {
         final byte[] content = readAllBytes("test3.xml");
         final ByteArrayOutputStream bout = new ByteArrayOutputStream();
         final GzipParameters parameters = new GzipParameters();
@@ -229,7 +161,7 @@ public final class GZipTest extends AbstractTest {
     }
 
     @Test
-    public void testInteroperabilityWithGZIPInputStream() throws Exception {
+    void testInteroperabilityWithGZIPInputStream() throws Exception {
         final byte[] content = readAllBytes("test3.xml");
         final ByteArrayOutputStream bout = new ByteArrayOutputStream();
         final GzipParameters parameters = new GzipParameters();
@@ -252,33 +184,43 @@ public final class GZipTest extends AbstractTest {
 
     @ParameterizedTest
     @ValueSource(ints = { 0, -1 })
-    public void testInvalidBufferSize(final int bufferSize) {
+    void testInvalidBufferSize(final int bufferSize) {
         final GzipParameters parameters = new GzipParameters();
         assertThrows(IllegalArgumentException.class, () -> parameters.setBufferSize(bufferSize), "IllegalArgumentException not thrown");
     }
 
     @ParameterizedTest
     @ValueSource(ints = { 10, -5 })
-    public void testInvalidCompressionLevel(final int compressionLevel) {
+    void testInvalidCompressionLevel(final int compressionLevel) {
         final GzipParameters parameters = new GzipParameters();
         assertThrows(IllegalArgumentException.class, () -> parameters.setCompressionLevel(compressionLevel), "IllegalArgumentException not thrown");
     }
 
     @Test
-    public void testMetadataRoundTrip() throws Exception {
+    void testMetadataRoundTrip() throws Exception {
         final ByteArrayOutputStream bout = new ByteArrayOutputStream();
 
         final GzipParameters parameters = new GzipParameters();
         parameters.setCompressionLevel(Deflater.BEST_COMPRESSION);
-        parameters.setModificationTime(123456000);
+        assertEquals(0, parameters.getModificationTime());
+        parameters.setModificationInstant(null);
+        assertEquals(0, parameters.getModificationTime());
+        parameters.setModificationInstant(MTIME_INSTANT);
+        assertEquals(MTIME_INSTANT.getEpochSecond(), parameters.getModificationTime());
+        assertEquals(MTIME_INSTANT, parameters.getModificationInstant());
+        parameters.setOS(GzipParameters.OS.Z_SYSTEM);
+        assertEquals(GzipParameters.OS.Z_SYSTEM, parameters.getOS());
+        parameters.setOS(null);
+        assertEquals(GzipParameters.OS.UNKNOWN, parameters.getOS());
         parameters.setOperatingSystem(13);
+        assertEquals(GzipParameters.OS.ACORN_RISCOS, parameters.getOS());
         parameters.setFilename("test3.xml");
         assertEquals(parameters.getFilename(), parameters.getFileName());
         parameters.setFileName("test3.xml");
         assertEquals(parameters.getFilename(), parameters.getFileName());
         parameters.setComment("Umlaute möglich?");
         try (GzipCompressorOutputStream out = new GzipCompressorOutputStream(bout, parameters)) {
-            Files.copy(getFile("test3" + ".xml").toPath(), out);
+            out.write(getFile("test3.xml"));
         }
 
         final GzipCompressorInputStream input = new GzipCompressorInputStream(new ByteArrayInputStream(bout.toByteArray()));
@@ -287,13 +229,14 @@ public final class GZipTest extends AbstractTest {
         assertEquals(Deflater.BEST_COMPRESSION, readParams.getCompressionLevel());
         assertEquals(123456000, readParams.getModificationTime());
         assertEquals(13, readParams.getOperatingSystem());
+        assertEquals(GzipParameters.OS.ACORN_RISCOS, readParams.getOS());
         assertEquals("test3.xml", readParams.getFileName());
         assertEquals("test3.xml", readParams.getFilename());
         assertEquals("Umlaute möglich?", readParams.getComment());
     }
 
     @Test
-    public void testMultiByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
+    void testMultiByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
         final File input = getFile("bla.tgz");
         final byte[] buf = new byte[2];
         try (InputStream is = Files.newInputStream(input.toPath());
@@ -305,14 +248,14 @@ public final class GZipTest extends AbstractTest {
     }
 
     @Test
-    public void testOverWrite() throws Exception {
+    void testOverWrite() throws Exception {
         final GzipCompressorOutputStream out = new GzipCompressorOutputStream(new ByteArrayOutputStream());
         out.close();
-        assertThrows(IOException.class, () -> out.write(0), "IOException expected");
+        assertThrows(IOException.class, () -> out.write(0));
     }
 
     @Test
-    public void testSingleByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
+    void testSingleByteReadConsistentlyReturnsMinusOneAtEof() throws IOException {
         final File input = getFile("bla.tgz");
         try (InputStream is = Files.newInputStream(input.toPath());
                 GzipCompressorInputStream in = new GzipCompressorInputStream(is)) {
